@@ -1,9 +1,6 @@
 OC.L10N.register(
     "files",
     {
-    "Storage is temporarily not available" : "พื้นที่จัดเก็บข้อมูลไม่สามารถใช้งานได้ชั่วคราว",
-    "Storage invalid" : "การจัดเก็บข้อมูลไม่ถูกต้อง",
-    "Unknown error" : "ข้อผิดพลาดที่ไม่รู้จัก",
     "File could not be found" : "ไม่พบไฟล์",
     "Move or copy" : "ย้ายหรือคัดลอก",
     "Download" : "ดาวน์โหลด",
@@ -13,7 +10,6 @@ OC.L10N.register(
     "Show grid view" : "แสดงมุมมองตาราง",
     "Home" : "หน้าหลัก",
     "Close" : "ปิด",
-    "Favorites" : "รายการโปรด",
     "Could not create folder \"{dir}\"" : "ไม่สามารถสร้างโฟลเดอร์ \"{dir}\"",
     "This will stop your current uploads." : "การกระทำนี้จะหยุดการอัปโหลดปัจจุบันของคุณ",
     "Upload cancelled." : "การอัปโหลดถูกยกเลิก",
@@ -26,6 +22,8 @@ OC.L10N.register(
     "An unknown error has occurred" : "เกิดข้อผิดพลาดที่ไม่รู้จัก",
     "File could not be uploaded" : "ไม่สามารถอัปโหลดไฟล์",
     "Uploading …" : "กำลังอัปโหลด …",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "กำลังอัปโหลด … ({currentNumber}/{total})",
     "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} จาก {totalSize} ({bitrate})",
     "Uploading that item is not supported" : "ไม่รองรับการอัปโหลดสิ่งนั้น",
     "Target folder does not exist any more" : "ไม่มีโฟลเดอร์เป้าหมายอีกต่อไป",
@@ -36,11 +34,12 @@ OC.L10N.register(
     "Move" : "ย้าย",
     "Copy" : "คัดลอก",
     "Choose target folder" : "เลือกโฟลเดอร์เป้าหมาย",
+    "Edit locally" : "แก้ไขในต้นทาง",
     "Open" : "เปิด",
-    "Delete file" : "ลบไฟล์",
-    "Delete folder" : "ลบโฟลเดอร์",
-    "Disconnect storage" : "ยกเลิกการเชื่อมต่อพื้นที่จัดเก็บข้อมูล",
-    "Leave this share" : "ออกจากการแชร์นี้",
+    "_Delete file_::_Delete files_" : ["ลบไฟล์"],
+    "_Delete folder_::_Delete folders_" : ["ลบโฟลเดอร์"],
+    "_Disconnect storage_::_Disconnect storages_" : ["เลิกเชื่อมต่อพื้นที่จัดเก็บข้อมูล"],
+    "_Leave this share_::_Leave these shares_" : ["ออกจากการแชร์เหล่านี้"],
     "Could not load info for file \"{file}\"" : "ไม่สามารถโหลดข้อมูลสำหรับไฟล์ \"{file}\"",
     "Files" : "ไฟล์",
     "Details" : "รายละเอียด",
@@ -52,6 +51,7 @@ OC.L10N.register(
     "Unable to determine date" : "ไม่สามารถระบุวัน",
     "This operation is forbidden" : "การดำเนินการนี้ถูกห้าม",
     "This directory is unavailable, please check the logs or contact the administrator" : "ไม่สามารถใช้งานไดเรกทอรีนี้ โปรดตรวจสอบบันทึกหรือติดต่อผู้ดูแลระบบ",
+    "Storage is temporarily not available" : "พื้นที่จัดเก็บข้อมูลไม่สามารถใช้งานได้ชั่วคราว",
     "Could not move \"{file}\", target exists" : "ไม่สามารถย้าย \"{file}\" เป้าหมายมีอยู่แล้ว",
     "Could not move \"{file}\"" : "ไม่สามารถย้ายไฟล์ \"{file}\"",
     "copy" : "คัดลอก",
@@ -59,6 +59,7 @@ OC.L10N.register(
     "Could not copy \"{file}\"" : "ไม่สามารถคัดลอก \"{file}\"",
     "Copied {origin} inside {destination}" : "คัดลอก {origin} ไว้ใน {destination} แล้ว",
     "Copied {origin} and {nbfiles} other files inside {destination}" : "คัดลอก {origin} และ {nbfiles} ไฟล์อื่น ๆ ไว้ใน {destination} แล้ว",
+    "Failed to redirect to client" : "เปลี่ยนเส้นทางไปยังไคลเอ็นต์ล้มเหลว",
     "{newName} already exists" : "{newName} มีอยู่แล้ว",
     "Could not rename \"{fileName}\", it does not exist any more" : "ไม่สามารถเปลี่ยนชื่อไฟล์ \"{fileName}\" ไฟล์นั้นไม่มีอยู่",
     "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "ชื่อ \"{targetName}\" มีอยู่แล้วในโฟลเดอร์ \"{dir}\" กรุณาเปลี่ยนชื่อใหม่",
@@ -79,7 +80,10 @@ OC.L10N.register(
     "_including %n hidden_::_including %n hidden_" : ["รวมถึง %n ไฟล์ที่ซ่อนอยู่"],
     "You do not have permission to upload or create files here" : "คุณไม่ได้รับอนุญาตให้อัปโหลดหรือสร้างไฟล์ที่นี่",
     "_Uploading %n file_::_Uploading %n files_" : ["กำลังอัปโหลด %n ไฟล์"],
+    "New" : "ใหม่",
+    "New file/folder menu" : "เมนูไฟล์/โฟลเดอร์ใหม่",
     "Select file range" : "เลือกช่วงไฟล์",
+    "{used}%" : "{used}%",
     "{used} of {quota} used" : "ใช้ไป {used} จาก {quota}",
     "{used} used" : "ใช้ไป {used}",
     "\"{name}\" is an invalid file name." : "\"{name}\" เป็นชื่อไฟล์ที่ไม่ถูกต้อง",
@@ -96,14 +100,14 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "พื้นที่จัดเก็บข้อมูลของคุณใกล้เต็มแล้ว ({usedSpacePercent}%)",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["ตรงกับ \"{filter}\""],
     "View in folder" : "ดูในโฟลเดอร์",
-    "Copied!" : "คัดลอกแล้ว",
-    "Copy direct link (only works for users who have access to this file/folder)" : "คัดลอกลิงก์โดยตรง (ใช้ได้เฉพาะผู้ใช้ที่มีสิทธิ์เข้าถึงไฟล์/โฟลเดอร์นี้)",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "คัดลอกลิงก์โดยตรงแล้ว (ใช้ได้เฉพาะผู้ใช้ที่มีสิทธิ์เข้าถึงไฟล์/โฟลเดอร์นี้)",
     "Path" : "เส้นทาง",
     "_%n byte_::_%n bytes_" : ["%n ไบต์"],
     "Favorited" : "เพิ่มในรายการโปรดแล้ว",
     "Favorite" : "รายการโปรด",
-    "You can only favorite a single file or folder at a time" : "คุณสามารถระบุเป็นรายการโปรดได้แค่ครั้งละ 1 ไฟล์หรือโฟลเดอร์",
+    "Copy direct link (only works for people who have access to this file/folder)" : "คัดลอกลิงก์โดยตรง (ใช้ได้เฉพาะผู้ใช้ที่มีสิทธิ์เข้าถึงไฟล์/โฟลเดอร์นี้)",
     "New folder" : "โฟลเดอร์ใหม่",
+    "Create new folder" : "สร้างโฟลเดอร์ใหม่",
     "Upload file" : "อัปโหลดไฟล์",
     "Recent" : "ล่าสุด",
     "Not favorited" : "ไม่ได้เป็นรายการโปรด",
@@ -114,6 +118,7 @@ OC.L10N.register(
     "Removed from favorites" : "เอาออกจากรายการโปรดแล้ว",
     "You added {file} to your favorites" : "คุณได้เพิ่ม {file} ในรายการโปรดของคุณ",
     "You removed {file} from your favorites" : "คุณได้เอา {file} ออกจากรายการโปรดของคุณ",
+    "Favorites" : "รายการโปรด",
     "File changes" : "การเปลี่ยนแปลงไฟล์",
     "Created by {user}" : "สร้างโดย {user}",
     "Changed by {user}" : "เปลี่ยนแปลงโดย {user}",
@@ -121,7 +126,7 @@ OC.L10N.register(
     "Restored by {user}" : "กู้คืนโดย {user}",
     "Renamed by {user}" : "เปลี่ยนชื่อโดย {user}",
     "Moved by {user}" : "ย้ายโดย {user}",
-    "\"remote user\"" : "\"ผู้ใช้รีโมท\"",
+    "\"remote account\"" : "\"บัญชีระยะไกล\"",
     "You created {file}" : "คุณได้สร้าง {file}",
     "You created an encrypted file in {file}" : "คุณได้สร้างไฟล์ที่เข้ารหัสใน {file}",
     "{user} created {file}" : "{user} ได้สร้าง {file}",
@@ -150,8 +155,6 @@ OC.L10N.register(
     "A file has been added to or removed from your <strong>favorites</strong>" : "มีไฟล์ที่ถูกเพิ่มเข้าหรือเอาออกจาก<strong>รายการโปรด</strong>ของคุณ",
     "A file or folder has been <strong>changed</strong>" : "มีไฟล์หรือโฟลเดอร์ที่มีการ<strong>เปลี่ยนแปลง</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "มีไฟล์หรือโฟลเดอร์ในรายการโปรดที่มีการ<strong>เปลี่ยนแปลง</strong>",
-    "All files" : "ไฟล์ทั้งหมด",
-    "Unlimited" : "ไม่จำกัด",
     "Upload (max. %s)" : "อัปโหลด (สูงสุด %s)",
     "Accept" : "ยอมรับ",
     "Reject" : "ปฏิเสธ",
@@ -165,60 +168,78 @@ OC.L10N.register(
     "The ownership transfer of {path} from {user} has completed." : "การโอนย้ายความเป็นเจ้าของของ {path} จาก {user} สำเร็จแล้ว",
     "in %s" : "ใน %s",
     "File Management" : "การจัดการไฟล์",
+    "You don’t have permission to upload or create files here" : "คุณไม่ได้รับอนุญาตให้อัปโหลดหรือสร้างไฟล์ที่นี่",
+    "Folder name" : "ชื่อโฟลเดอร์",
+    "File not found" : "ไม่พบไฟล์",
+    "Storage informations" : "ข้อมูลพื้นที่จัดเก็บ",
+    "{usedQuotaByte} used" : "ใช้ไป {usedQuotaByte}",
+    "{relative}% used" : "ใช้ไป {relative}%",
+    "Could not refresh storage stats" : "ไม่สามารถรีเฟรชสถิติพื้นที่จัดเก็บ",
+    "Your storage is full, files can not be updated or synced anymore!" : "พื้นที่จัดเก็บข้อมูลของคุณเต็มแล้ว ไม่สามารถอัปเดตหรือซิงค์ไฟล์ได้อีก!",
+    "Create" : "สร้าง",
     "Transfer ownership of a file or folder" : "โอนย้ายความเป็นเจ้าของไฟล์หรือโฟลเดอร์",
     "Choose file or folder to transfer" : "เลือกไฟล์หรือโฟลเดอร์ที่จะโอนย้าย",
     "Change" : "เปลี่ยนแปลง",
     "New owner" : "เจ้าของใหม่",
-    "Search users" : "ค้นหาผู้ใช้",
     "Choose a file or folder to transfer" : "เลือกไฟล์หรือโฟลเดอร์ที่จะโอนย้าย",
     "Transfer" : "โอนย้าย",
     "Transfer {path} to {userid}" : "โอนย้าย {path} ไปยัง {userid}",
     "Invalid path selected" : "เลือกเส้นทางไม่ถูกต้อง",
+    "Unknown error" : "ข้อผิดพลาดที่ไม่รู้จัก",
     "Ownership transfer request sent" : "ส่งคำขอโอนย้ายความเป็นเจ้าของแล้ว",
     "Cannot transfer ownership of a file or folder you do not own" : "ไม่สามารถโอนย้ายความเป็นเจ้าของไฟล์หรือโฟลเดอร์ที่คุณไม่ได้เป็นเจ้าของ",
+    "Choose {file}" : "เลือก {file}",
+    "No files in here" : "ไม่มีไฟล์ที่นี่",
+    "Upload some content or sync with your devices!" : "ลองอัปโหลดเนื้อหาหรือซิงค์กับอุปกรณ์อื่นของคุณ",
+    "Go back" : "กลับไป",
+    "Shared by link" : "แชร์โดยลิงก์",
+    "Shared" : "ถูกแชร์",
+    "Open the files app settings" : "เปิดการตั้งค่าแอปไฟล์",
+    "Files settings" : "การตั้งค่าไฟล์",
+    "Show hidden files" : "แสดงไฟล์ที่ซ่อนอยู่",
+    "Crop image previews" : "ครอปตัดรูปภาพตัวอย่าง",
+    "Additional settings" : "การตั้งค่าเพิ่มเติม",
+    "WebDAV" : "WebDAV",
+    "Copy to clipboard" : "คัดลอกไปยังคลิปบอร์ด",
+    "Use this address to access your Files via WebDAV" : "ใช้ที่อยู่นี้เพื่อเข้าถึงไฟล์ของคุณผ่าน WebDAV",
+    "Clipboard is not available" : "คลิปบอร์ดไม่พร้อมใช้งาน",
     "Unable to change the favourite state of the file" : "ไม่สามารถเปลี่ยนสถานะรายการโปรดของไฟล์",
     "Error while loading the file data" : "ข้อผิดพลาดขณะโหลดข้อมูลไฟล์",
     "Pick a template for {name}" : "เลือกเทมเพลตสำหรับ {name}",
-    "Cancel" : "ยกเลิก",
-    "Create" : "สร้าง",
     "Create a new file with the selected template" : "สร้างไฟล์ใหม่ด้วยเทมเพลตที่เลือก",
     "Creating file" : "กำลังสร้างไฟล์",
     "Blank" : "ว่าง",
     "Unable to create new file from template" : "ไม่สามารถสร้างไฟล์ใหม่จากเทมเพลต",
-    "Set up templates folder" : "ตั้งค่าโฟลเดอร์เทมเพลต",
-    "Templates" : "เทมเพลต",
+    "Delete permanently" : "ลบแบบถาวร",
+    "Cancel" : "ยกเลิก",
+    "Copy to {target}" : "คัดลอกไปยัง {target}",
+    "Move to {target}" : "ย้ายไปยัง {target}",
+    "Filename" : "ชื่อไฟล์",
     "Unable to initialize the templates directory" : "ไม่สามารถเตรียมไดเรกทอรีเทมเพลต",
-    "%s used" : "ใช้ไป %s",
-    "%1$s of %2$s used" : "ใช้ไป %1$s จาก %2$s",
-    "Files settings" : "การตั้งค่าไฟล์",
-    "Show hidden files" : "แสดงไฟล์ที่ซ่อนอยู่",
-    "Crop image previews" : "ครอปตัดรูปภาพตัวอย่าง",
-    "WebDAV" : "WebDAV",
-    "Use this address to access your Files via WebDAV" : "ใช้ที่อยู่นี้เพื่อเข้าถึงไฟล์ของคุณผ่าน WebDAV",
-    "Toggle %1$s sublist" : "สลับรายการย่อย %1$s",
-    "Toggle grid view" : "สลับมุมมองตาราง",
-    "No files in here" : "ไม่มีไฟล์ที่นี่",
-    "Upload some content or sync with your devices!" : "ลองอัปโหลดเนื้อหาหรือซิงค์กับอุปกรณ์อื่นของคุณ",
+    "Templates" : "เทมเพลต",
+    "No favorites yet" : "ยังไม่มีรายการโปรด",
+    "Files and folders you mark as favorite will show up here" : "ไฟล์และโฟลเดอร์ที่คุณระบุเป็นรายการโปรดจะแสดงที่นี่",
+    "All files" : "ไฟล์ทั้งหมด",
     "No entries found in this folder" : "ไม่พบรายการในโฟลเดอร์นี้",
     "Select all" : "เลือกทั้งหมด",
     "Upload too large" : "ไฟล์ที่อัปโหลดมีขนาดใหญ่เกินไป",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "ไฟล์ที่คุณพยายามที่จะอัปโหลดมีขนาดเกินกว่าขนาดสูงสุดที่อัปโหลดได้สำหรับเซิร์ฟเวอร์นี้",
-    "No favorites yet" : "ยังไม่มีรายการโปรด",
-    "Files and folders you mark as favorite will show up here" : "ไฟล์และโฟลเดอร์ที่คุณระบุเป็นรายการโปรดจะแสดงที่นี่",
+    "Text file" : "ไฟล์ข้อความ",
+    "New text file.txt" : "ไฟล์ข้อความใหม่.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "คัดลอกลิงก์โดยตรงแล้ว (ใช้ได้เฉพาะผู้ใช้ที่มีสิทธิ์เข้าถึงไฟล์/โฟลเดอร์นี้)",
+    "Copy direct link (only works for users who have access to this file/folder)" : "คัดลอกลิงก์โดยตรง (ใช้ได้เฉพาะผู้ใช้ที่มีสิทธิ์เข้าถึงไฟล์/โฟลเดอร์นี้)",
+    "You can only favorite a single file or folder at a time" : "คุณสามารถระบุเป็นรายการโปรดได้แค่ครั้งละ 1 ไฟล์หรือโฟลเดอร์",
+    "\"remote user\"" : "\"ผู้ใช้รีโมท\"",
+    "Search users" : "ค้นหาผู้ใช้",
+    "Set up templates folder" : "ตั้งค่าโฟลเดอร์เทมเพลต",
+    "Toggle %1$s sublist" : "สลับรายการย่อย %1$s",
+    "Toggle grid view" : "สลับมุมมองตาราง",
     "Deleted files" : "ไฟล์ที่ถูกลบ",
     "Shares" : "การแชร์",
     "Shared with others" : "แชร์กับผู้อื่น",
     "Shared with you" : "แชร์กับคุณ",
-    "Shared by link" : "แชร์โดยลิงก์",
     "Deleted shares" : "การแชร์ที่ถูกลบ",
     "Pending shares" : "การแชร์ที่กำลังดำเนินการ",
-    "Text file" : "ไฟล์ข้อความ",
-    "New text file.txt" : "ไฟล์ข้อความใหม่.txt",
-    "Select" : "เลือก",
-    "You don’t have permission to upload or create files here" : "คุณไม่ได้รับอนุญาตให้อัปโหลดหรือสร้างไฟล์ที่นี่",
-    "New" : "สร้างใหม่",
-    "Cannot transfer ownership of a file or folder you don't own" : "ไม่สามารถโอนย้ายความเป็นเจ้าของไฟล์หรือโฟลเดอร์ที่คุณไม่ได้เป็นเจ้าของ",
-    "%s%% of %s used" : "ใช้ไป %s%% จาก %s",
-    "Settings" : "การตั้งค่า"
+    "Choose" : "เลือก"
 },
 "nplurals=1; plural=0;");
