@@ -1,31 +1,6 @@
 OC.L10N.register(
     "files_sharing",
     {
-    "Shared with you" : "和你共享的",
-    "Nothing shared with you yet" : "您还没有收到任何共享的文件",
-    "Files and folders others share with you will show up here" : "其它人共享给您的文件和文件夹将显示在这里",
-    "Shared with others" : "您共享的文件",
-    "Nothing shared yet" : "还没有共享过文件",
-    "Files and folders you share will show up here" : "您共享的文件和文件夹将显示在这里",
-    "Shared by link" : "通过链接共享",
-    "No shared links" : "无共享链接",
-    "Files and folders you share by link will show up here" : "您通过链接共享的文件和文件夹将显示在这里",
-    "Deleted shares" : "已删除的共享",
-    "No deleted shares" : "没有删除的共享",
-    "Shares you deleted will show up here" : "您删除的共享将在这里显示",
-    "Pending shares" : "待定共享",
-    "No pending shares" : "没有待定共享",
-    "Shares you have received but not confirmed will show up here" : "您收到但未确认的共享将显示在这里",
-    "Shares" : "共享",
-    "No shares" : "没有共享",
-    "Shares will show up here" : "共享将在这里显示",
-    "Restore" : "恢复",
-    "Restore share" : "恢复共享",
-    "Something happened. Unable to restore the share." : "发生了问题。无法恢复该共享。",
-    "Accept share" : "接受共享",
-    "Something happened. Unable to accept the share." : "发生了问题。无法接受该共享。",
-    "Reject share" : "拒绝共享",
-    "Something happened. Unable to reject the share." : "发生了问题。无法拒绝该共享。",
     "Waiting…" : "等待中...",
     "error" : "错误",
     "finished" : "完成",
@@ -39,9 +14,7 @@ OC.L10N.register(
     "Show grid view" : "显示网格视图",
     "No compatible server found at {remote}" : " {remote} 未发现匹配的服务器",
     "Invalid server URL" : "无效的服务器地址",
-    "Failed to add the public link to your Nextcloud" : "无法添加公开链接到您的 Nextcloud",
-    "No expiration date set" : "未设置失效时间",
-    "Shared by" : "共享人",
+    "Failed to add the public link to your Nextcloud" : "添加公开链接到您的Nextcloud失败",
     "File shares" : "文件共享",
     "Downloaded via public link" : "通过公开链接下载",
     "Downloaded by {email}" : "已被 {email} 下载",
@@ -54,7 +27,7 @@ OC.L10N.register(
     "Share for group {group} expired" : "给分组 {group} 的共享已过期",
     "You shared {file} with group {group}" : "您与群组 {group} 共享了 {file} ",
     "You removed group {group} from {file}" : "已从 {file} 移除组 {group}",
-    "{actor} shared {file} with group {group}" : " {actor} 与群组 {group} 共享了 {file} ",
+    "{actor} shared {file} with group {group}" : "{actor} 与群组 {group} 共享了 {file} ",
     "{actor} removed group {group} from {file}" : "{actor} 从 {file} 删除群组 {group} ",
     "Share for file {file} with group {group} expired" : "与分组 {group} 的文件共享 {file} 已过期",
     "Shared as public link" : "共享为公开链接",
@@ -74,7 +47,7 @@ OC.L10N.register(
     "You received a new remote share {file} from {user}" : "您收到了一个来自 {user} 的远程共享 {file} ",
     "{user} accepted the remote share of {file}" : "{user} 接受了 {file} 的远程共享",
     "{user} declined the remote share of {file}" : "{user} 拒绝了 {file} 的远程共享",
-    "{user} unshared {file} from you" : "你取消了 {user} 共享的文件 {file}",
+    "{user} unshared {file} from you" : "{user} 取消与您共享 {file}",
     "Shared with {user}" : "与 {user} 共享",
     "Removed share for {user}" : "移除给 {user} 的共享",
     "You removed yourself" : "您移除了您自己",
@@ -98,7 +71,7 @@ OC.L10N.register(
     "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "通过邮件或公共链接共享的文件或文件夹<strong>已下载</strong>",
     "A file or folder was shared from <strong>another server</strong>" : "<strong>其它服务器</strong> 中一个文件或者文件夹被共享 ",
     "Files" : "文件",
-    "A file or folder has been <strong>shared</strong>" : "一个文件或文件夹已<strong>共享</strong>。",
+    "A file or folder has been <strong>shared</strong>" : "一个文件或文件夹已<strong>共享</strong>",
     "Shared link" : "已共享的链接",
     "Wrong share ID, share does not exist" : "错误的分享 ID，分享不存在",
     "Could not delete share" : "不能删除共享",
@@ -106,20 +79,19 @@ OC.L10N.register(
     "Wrong path, file/folder does not exist" : "错误的路径，文件/文件夹不存在",
     "Could not create share" : "无法创建共享",
     "Invalid permissions" : "无效的权限 ",
-    "Please specify a valid user" : "请指定一个有效的用户",
     "Group sharing is disabled by the administrator" : "群组共享已被管理员禁用",
     "Please specify a valid group" : "请指定一个有效的组",
     "Public link sharing is disabled by the administrator" : "公共链接共享已被管理员禁用",
     "Public upload disabled by the administrator" : "公共上传已被管理员禁用",
     "Public upload is only possible for publicly shared folders" : "公共上传仅适用于公共共享文件夹",
-    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "由于 Nextcloud Talk 没有启用，所以通过 Nextcloud Talk 发送 %s 共享密码失败。",
-    "Invalid date, date format must be YYYY-MM-DD" : "无效的日期，日期格式必须是 YYYY-MM-DD",
+    "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "由于 Nextcloud 通话应用没有启用，所以通过 Nextcloud 通话应用发送%s共享密码失败。",
     "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "共享 %1$s 失败，后端不允许类型为 %2$s 的共享",
-    "Please specify a valid federated user ID" : "请指定一个有效的联邦用户 ID",
-    "Please specify a valid federated group ID" : "请指定一个有效的联邦群组 ID",
+    "Invalid date, date format must be YYYY-MM-DD" : "无效的日期，日期格式必须是 YYYY-MM-DD",
+    "Please specify a valid federated group ID" : "请指定一个有效的联合群组 ID",
     "You cannot share to a Circle if the app is not enabled" : "如果这个应用程序不可用，您不能共享到圈子",
     "Please specify a valid circle" : "请指明一个可用圈子",
     "Sharing %s failed because the back end does not support room shares" : "由于后端不支持房间共享，所以共享 %s 失败。",
+    "Sharing %s failed because the back end does not support ScienceMesh shares" : "共享 %s 失败，因为后端不支持 ScienceMesh 共享。",
     "Unknown share type" : "未知共享类型",
     "Not a directory" : "不是一个目录",
     "Could not lock node" : "无法锁定节点",
@@ -127,23 +99,20 @@ OC.L10N.register(
     "Wrong or no update parameter given" : "错误或没有更新参数给出",
     "Share must at least have READ or CREATE permissions" : "分享至少具有 READ 或 CREATE 权限",
     "Share must have READ permission if UPDATE or DELETE permission is set" : "分享如果设置了 UPDATE 或 DELETE 权限，则必须具有 READ 权限",
-    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "“通过Nextcloud Talk发送密码”共享文件或文件夹失败了，因为未启用 Nextcloud Talk",
+    "\"Sending the password by Nextcloud Talk\" for sharing a file or folder failed because Nextcloud Talk is not enabled." : "“通过 Nextcloud 通话应用发送密码”共享文件或文件夹失败了，因为未启用Nextcloud 通话应用",
     "shared by %s" : "共享者 %s",
     "Download all files" : "下载所有文件",
     "Direct link" : "直接链接",
-    "Add to your %s" : "添加到你的 %s",
+    "Add to your %s" : "添加到您的 %s",
     "Share API is disabled" : "共享 API 已被禁用",
     "File sharing" : "文件共享",
     "Share will expire tomorrow" : "共享将在明天过期",
-    "One or more of your shares will expire tomorrow" : "您的一个或多个共享将在明天过期",
-    "Your share of {node} will expire tomorrow" : "您在{node}的共享将在明天过期",
+    "Your share of {node} will expire tomorrow" : "您在 {node} 的共享将在明天过期",
     "You received {share} as a share by {user}" : "您收到了 {user} 共享的 {share}",
     "You received {share} to group {group} as a share by {user}" : "您收到了来自 {user} 的共享给分组 {group} 的 {share}",
     "Accept" : "接受",
-    "Reject" : "拒绝",
-    "This application enables users to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable users can then share files and folders with other users and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other users outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "这个应用程序允许用户在 Nextcloud 内部共享文件。如果启用，管理员能够选择哪个组可以共享文件。然后，可用的用户能够共享文件和文件夹给 Nextcloud 中的其他用户和组。另外，如果管理员启用了共享链接功能，能够使用外部链接将文件共享给 Nextcloud 之外的其他用户。管理员也可以强制设置密码，过期日期，并且可以通过共享链接启用服务器到服务器的共享，以及从移动设备共享。\n关闭该功能将删除服务器上所有共享接收者以用同步客户端和移动应用上的共享文件和文件夹。更多信息可查阅 Nextcloud 文档。",
+    "Decline" : "拒绝",
     "Sharing" : "共享",
-    "Accept user and group shares by default" : "默认接受用户和分组共享",
     "Error while toggling options" : "切换选项时出错",
     "Set default folder for accepted shares" : "设置已接受共享的默认文件夹",
     "Reset" : "重置",
@@ -151,23 +120,7 @@ OC.L10N.register(
     "Choose a default folder for accepted shares" : "为已接受的共享选择一个默认文件夹",
     "Invalid path selected" : "所选路径无效",
     "Unknown error" : "未知错误",
-    "Allow editing" : "允许编辑",
-    "Read only" : "只读",
-    "Allow upload and editing" : "允许上传和编辑",
-    "File drop (upload only)" : "文件拖放（仅上传）",
-    "Custom permissions" : "自定义权限",
-    "Read" : "读取",
-    "Upload" : "上传",
-    "Edit" : "编辑",
-    "Bundled permissions" : "权限包",
-    "Allow creating" : "允许创建",
-    "Allow deleting" : "允许删除",
-    "Allow resharing" : "允许二次共享",
-    "Expiration date enforced" : "强制过期日期",
-    "Set expiration date" : "设置过期日期",
-    "Enter a date" : "输入日期",
-    "Note to recipient" : "接收人备注",
-    "Unshare" : "取消共享",
+    "Open Sharing Details" : "打开分享详细信息",
     "group" : "分组",
     "conversation" : "会话",
     "remote" : "远程",
@@ -176,49 +129,85 @@ OC.L10N.register(
     "Shared with the group {user} by {owner}" : "{owner} 共享给分组 {user}",
     "Shared with the conversation {user} by {owner}" : "由{owner}共享给会话{user}",
     "Shared with {user} by {owner}" : "{owner} 共享给 {user}",
-    "Allow download" : "允许下载",
     "Added by {initiator}" : "由 {initiator} 添加",
-    "Via “{folder}”" : "通过 “{folder}”",
+    "Via “{folder}”" : "通过“{folder}”",
+    "Unshare" : "取消共享",
     "Internal link" : "内部链接",
+    "Cannot copy, please copy the link manually" : "无法复制，请手动复制链接",
     "Copy internal link to clipboard" : "复制内部链接到剪贴板",
     "Link copied" : "已复制链接",
-    "Cannot copy, please copy the link manually" : "无法复制，请手动复制链接",
-    "Copy to clipboard" : "复制到剪贴板",
-    "Only works for users with access to this folder" : "仅适用于有权限访问此文件夹的用户",
-    "Only works for users with access to this file" : "仅适用于有权限访问此文件的用户",
-    "Copy public link to clipboard" : "复制公开链接到剪贴板",
     "Please enter the following required information before creating the share" : "请在创建共享前输入以下必填信息",
     "Password protection (enforced)" : "密码保护（强制）",
     "Password protection" : "密码保护",
     "Enter a password" : "输入密码",
     "Expiration date (enforced)" : "过期日期（强制）",
+    "Enter a date" : "输入日期",
     "Create share" : "创建共享",
     "Cancel" : "取消",
-    "Share label" : "分享标签",
-    "Hide download" : "隐藏下载",
-    "Password protect" : "密码保护",
-    "Password expires {passwordExpirationTime}" : "密码于 {passwordExpirationTime} 过期",
-    "Password expired" : "密码已过期",
-    "Video verification" : "视频验证",
-    "Enter a note for the share recipient" : "给共享接收人留备注",
+    "Customize link" : "自定义链接",
     "Add another link" : "添加其他链接",
     "Create a new share link" : "创建新的共享链接",
     "{shareWith} by {initiator}" : "由 {initiator} 通过 {shareWith} 共享",
     "Shared via link by {initiator}" : "由 {initiator} 通过链接共享",
-    "Mail share ({label})" : "邮件分享 ({label})",
-    "Share link ({label})" : "分享链接({label})",
+    "Mail share ({label})" : "邮件分享（{label}）",
+    "Share link ({label})" : "分享链接（{label}）",
+    "Share link ({index})" : "分享链接（{index}）",
     "Share link" : "共享链接",
+    "Actions for \"{title}\"" : "“{title}”的动作",
+    "Copy public link of \"{title}\" to clipboard" : "将“{title}”的公开链接复制到剪贴板",
     "Error, please enter proper password and/or expiration date" : "错误，请输入正确的密码和/或过期日期",
-    "No recommendations. Start typing." : "没有推荐。开始输入。",
+    "Link share created" : "已创建链接分享",
+    "Error while creating the share" : "创建共享时出错",
+    "View only" : "仅查看",
+    "Can edit" : "可以编辑",
+    "File drop" : "文件拖放",
+    "Custom permissions" : "自定义权限",
+    "Search for share recipients" : "查找共享参与者",
+    "No recommendations. Start typing." : "没有建议。开始输入。",
     "Resharing is not allowed" : "不允许二次共享",
     "Name or email …" : "姓名或电子邮件 ...",
-    "Name, email, or Federated Cloud ID …" : "名称，电子邮件或联合云 ID ...",
+    "Name, email, or Federated Cloud ID …" : "名称、电子邮件或联合云 ID ...",
     "Searching …" : "正在搜索 ...",
     "No elements found." : "未发现元素。",
     "Search globally" : "全局搜索",
+    "Guest" : "访客",
+    "Group" : "群组",
+    "Email" : "电子邮箱",
+    "Talk conversation" : "通话应用对话",
+    "Deck board" : "看板",
+    "ScienceMesh" : "ScienceMesh",
     "on {server}" : "在 {server} 上",
+    "Allow upload and editing" : "允许上传和编辑",
+    "Allow editing" : "允许编辑",
+    "Upload only" : "仅上传",
+    "Advanced settings" : "高级选项",
+    "Share label" : "分享标签",
+    "Set password" : "设置密码",
+    "Password" : "密码",
+    "Password expires {passwordExpirationTime}" : "密码于 {passwordExpirationTime} 过期",
+    "Password expired" : "密码已过期",
+    "Video verification" : "视频验证",
+    "Set expiration date" : "设置过期日期",
+    "Expiration date" : "过期日期 ",
+    "Hide download" : "隐藏下载",
+    "Allow download" : "允许下载",
+    "Note to recipient" : "接收人备注",
+    "Enter a note for the share recipient" : "给共享接收人留备注",
+    "Read" : "读取",
+    "Create" : "创建",
+    "Edit" : "编辑",
+    "Share" : "共享",
+    "Delete share" : "删除共享",
+    "Share with {userName}" : "分享至 {userName}",
+    "Share with group" : "分享至群组",
+    "Share in conversation" : "分享至对话",
+    "Share with remote" : "分享至远程",
+    "Share with remote group" : "分享至远程群组",
+    "Share with guest" : "分享至访客",
+    "Share with" : "共享给",
+    "Save share" : "保存分享",
+    "Update share" : "更新分享",
     "Others with access" : "其他具有访问权限的人",
-    "No other users with access found" : "找不到其他具有访问权限的用户",
     "Toggle list of others with access to this directory" : "切换有权访问此目录的其他人的列表",
     "Toggle list of others with access to this file" : "切换有权访问此文件的其他人的列表",
     "Unable to fetch inherited shares" : "无法获取继承的共享",
@@ -226,28 +215,53 @@ OC.L10N.register(
     "Expires {relativetime}" : "过期 {relativetime}",
     "this share just expired." : "此共享已过期。",
     "Shared with you by {owner}" : "{owner} 与您共享",
+    "_Accept share_::_Accept shares_" : ["接受共享"],
+    "Open in Files" : "在文件中打开",
+    "_Reject share_::_Reject shares_" : ["拒绝共享"],
+    "_Restore share_::_Restore shares_" : ["恢复共享"],
+    "Shared" : "已共享",
+    "Shared by {ownerDisplayName}" : "由 {ownerDisplayName} 分享",
+    "Show sharing options" : "显示共享选项",
     "Link to a file" : "链接到文件",
     "Error creating the share: {errorMessage}" : "创建共享失败：{errorMessage}",
     "Error creating the share" : "创建共享时出错",
     "Error updating the share: {errorMessage}" : "更新共享失败：{errorMessage}",
     "Error updating the share" : "更新共享时出错",
-    "Shared" : "已共享",
-    "Share" : "共享",
+    "File \"{path}\" has been unshared" : "文件“{path}”已取消共享",
+    "Folder \"{path}\" has been unshared" : "文件夹“{path}”已取消共享",
+    "Share {propertyName} saved" : "共享 {propertyName} 已保存",
+    "Shared by" : "共享人",
     "Shared with" : "共享给",
+    "Password created successfully" : "成功创建密码",
+    "Error generating password from password policy" : "从密码策略生成密码时出错",
     "Shared with you and the group {group} by {owner}" : "{owner} 共享给您及 {group} 分组",
     "Shared with you and {circle} by {owner}" : "{owner} 共享给您及 {circle}",
     "Shared with you and the conversation {conversation} by {owner}" : "由{owner} 共享给您及对话 {conversation}",
     "Shared with you in a conversation by {owner}" : "由 {owner} 在一个会话中共享给您",
-    "No entries found in this folder" : "在此文件夹中找不到项目",
-    "Name" : "名称",
-    "Share time" : "共享时间",
-    "Expiration date" : "过期日期 ",
-    "Sorry, this link does not seem to work anymore." : "抱歉，此链接已失效。",
-    "Reasons might be:" : "可能原因是：",
-    "the item was removed" : "此项已移除",
-    "the link expired" : "链接过期",
-    "sharing is disabled" : "已禁用共享",
-    "For more info, please ask the person who sent this link." : "欲知详情，请联系发给您该链接的人。",
+    "Shares" : "共享",
+    "Overview of shared files." : "已分享文件的概览",
+    "No shares" : "没有共享",
+    "Files and folders you shared or have been shared with you will show up here" : "您共享或已与您共享的文件与文件夹将显示在此处",
+    "Shared with you" : "共享给您的",
+    "List of files that are shared with you." : "与您共享的文件列表",
+    "Nothing shared with you yet" : "您还没有收到任何共享的文件",
+    "Files and folders others shared with you will show up here" : "其他人与您分享的文件与文件夹将显示在此处",
+    "Shared with others" : "您共享的文件",
+    "List of files that you shared with others." : "你与其他人分享的文件列表。",
+    "Nothing shared yet" : "还没有共享过文件",
+    "Files and folders you shared will show up here" : "您分享的文件与文件夹将会显示在此处",
+    "Shared by link" : "通过链接共享",
+    "List of files that are shared by link." : "存在分享链接的文件列表",
+    "No shared links" : "无共享链接",
+    "Files and folders you shared by link will show up here" : "此处会显示您使用链接分享的文件和文件夹",
+    "Deleted shares" : "已删除的共享",
+    "List of shares you left." : "您已退出的分享列表",
+    "No deleted shares" : "没有删除的共享",
+    "Shares you have left will show up here" : "此处会显示您退出的分享",
+    "Pending shares" : "待定共享",
+    "List of unapproved shares." : "未批准的分享列表",
+    "No pending shares" : "没有待定共享",
+    "Shares you have received but not approved will show up here" : "您已收到但未批准的分享将显示在这里",
     "Share note" : "共享笔记",
     "Upload files to %s" : "上传文件到 %s",
     "Note" : "备注",
@@ -256,11 +270,47 @@ OC.L10N.register(
     "Uploaded files:" : "上传的文件： ",
     "By uploading files, you agree to the %1$sterms of service%2$s." : "通过上传文件，您同意了 %1$s 服务条款 %2$s。",
     "Add to your Nextcloud" : "添加到您的 Nextcloud",
-    "Wrong share ID, share doesn't exist" : "错误的共享 ID，共享不存在",
-    "Wrong path, file/folder doesn't exist" : "路径错误，文件或文件夹不存在",
-    "Cannot change permissions for public share links" : "无法更改公共共享链接的权限 ",
-    "Sharing sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "由于 Nextcloud Talk 没有启用，所以通过 Nextcloud Talk 发送共享密码失败。",
-    "Sorry, this link doesn’t seem to work anymore." : "抱歉，此链接已失效。",
-    "Toggle grid view" : "切换网格视图"
+    "Files and folders others share with you will show up here" : "其它人共享给您的文件和文件夹将显示在这里",
+    "Files and folders you share will show up here" : "您共享的文件和文件夹将显示在这里",
+    "Files and folders you share by link will show up here" : "您通过链接共享的文件和文件夹将显示在这里",
+    "Shares you deleted will show up here" : "您删除的共享将在这里显示",
+    "Shares you have received but not confirmed will show up here" : "您收到但未确认的共享将显示在这里",
+    "Shares will show up here" : "共享将在这里显示",
+    "Restore" : "恢复",
+    "Something happened. Unable to restore the share." : "发生了问题。无法恢复该共享。",
+    "Something happened. Unable to accept the share." : "发生了问题。无法接受该共享。",
+    "Something happened. Unable to reject the share." : "发生了问题。无法拒绝该共享。",
+    "No expiration date set" : "未设置失效时间",
+    "Please specify a valid user" : "请指定一个有效的用户",
+    "Please specify a valid federated user ID" : "请指定一个有效的联合用户 ID",
+    "Sharing %s failed because the back end does not support sciencemesh shares" : "共享 %s 失败，因为后端不支持 ScienceMesh 共享。",
+    "Reject" : "拒绝",
+    "This application enables users to share files within Nextcloud. If enabled, the admin can choose which groups can share files. The applicable users can then share files and folders with other users and groups within Nextcloud. In addition, if the admin enables the share link feature, an external link can be used to share files with other users outside of Nextcloud. Admins can also enforce passwords, expirations dates, and enable server to server sharing via share links, as well as sharing from mobile devices.\nTurning the feature off removes shared files and folders on the server for all share recipients, and also on the sync clients and mobile apps. More information is available in the Nextcloud Documentation." : "这个应用程序允许用户在 Nextcloud 内部共享文件。如果启用，管理员能够选择哪个组可以共享文件。然后，可用的用户能够共享文件和文件夹给 Nextcloud 中的其他用户和组。另外，如果管理员启用了共享链接功能，能够使用外部链接将文件共享给 Nextcloud 之外的其他用户。管理员也可以强制设置密码，过期日期，并且可以通过共享链接启用服务器到服务器的共享，以及从移动设备共享。\n关闭该功能将删除服务器上所有共享接收者以用同步客户端和移动应用上的共享文件和文件夹。更多信息可查阅 Nextcloud 文档。",
+    "Accept user and group shares by default" : "默认接受用户和分组共享",
+    "Read only" : "只读",
+    "File drop (upload only)" : "文件拖放（仅上传）",
+    "Upload" : "上传",
+    "Bundled permissions" : "权限包",
+    "Allow creating" : "允许创建",
+    "Allow deleting" : "允许删除",
+    "Allow resharing" : "允许二次共享",
+    "Expiration date enforced" : "强制过期日期",
+    "Only works for users with access to this folder" : "仅适用于有权限访问此文件夹的用户",
+    "Only works for users with access to this file" : "仅适用于有权限访问此文件的用户",
+    "Password protect" : "密码保护",
+    "Circle" : "圈子",
+    "Science Mesh" : "Science Mesh",
+    "No other users with access found" : "找不到其他具有访问权限的用户",
+    "No entries found in this folder" : "在此文件夹中找不到项目",
+    "Name" : "名称",
+    "Share time" : "共享时间",
+    "Sorry, this link does not seem to work anymore." : "抱歉，此链接已失效。",
+    "Reasons might be:" : "可能原因是：",
+    "the item was removed" : "此项已移除",
+    "the link expired" : "链接过期",
+    "sharing is disabled" : "已禁用共享",
+    "For more info, please ask the person who sent this link." : "如需了解更多信息，请联系发给您该链接的人。",
+    "Update" : "更新",
+    "Share with " : "分享给"
 },
 "nplurals=1; plural=0;");
