@@ -10,121 +10,164 @@ OC.L10N.register(
     "Collaborative albums" : "Спільні альбоми",
     "People" : "Люди",
     "Folders" : "Каталоги",
-    "Favorites" : "Улюблене",
+    "Favorites" : "Із зірочкою",
     "On this day" : "Цього дня",
     "Shared with you" : "Вам надано доступ",
-    "Tags" : "Позначки",
-    "Locations" : "Розташування",
-    "Photos settings" : "Налаштування фотографій",
+    "Tags" : "Мітки",
+    "Places" : "Місця",
+    "Map" : "Мапа",
+    "Photos settings" : "Налаштування",
     "Mark selection as favorite" : "Позначити вибране як вибране",
     "Add selection to favorites" : "Додайте вибір до вибраного",
-    "Remove selection from favorites" : "Видалити вибір із вибраного",
+    "Remove selection from favorites" : "Вилучити вибір із вибраного",
     "Name of the album" : "Назва альбому",
     "Location of the album" : "Розташування альбому",
-    "Go back to the previous view." : "Повернутися до попереднього перегляду.",
     "Back" : "Назад",
-    "Go to the add collaborators view." : "Перейдіть до перегляду додавання співавторів.",
     "Add collaborators" : "Додайте співавторів",
-    "Save." : "Зберегти.",
-    "Create the album." : "Створіть альбом.",
     "Save" : "Зберегти",
     "Create album" : "Створити альбом",
-    "Back to the new album form." : "Повернутися до форми нового альбому.",
     "Add to Album" : "Додати в альбом",
+    "Add selection to album {albumName}" : "Додати виділення до альбому {albumName}",
+    "Shared by" : "Поділилися",
     "Create a new album." : "Створіть новий альбом.",
     "Create new album" : "Створити новий альбом",
     "New album" : "Новий альбом",
     "_%n item_::_%n photos and videos_" : ["%n фотографії та відео","%n фотографії та відео","%n фотографії та відео","%n фотографії та відео"],
-    "_Share with %n user_::_Share with %n users_" : ["Поділіться з %n користувачем","Поділіться з %n користувачами","Поділіться з %n користувачами","Поділіться з %n користувачами"],
     "Add people or groups who can edit your album" : "Додайте людей або групи, які можуть редагувати ваш альбом",
-    "Search for collaborators" : "Пошук співавторів",
     "Search people or groups" : "Пошук людей або груп",
-    "Add {collaboratorLabel} to the collaborators list" : "Додайте {collaboratorLabel} до списку співавторів",
-    "No collaborators available" : "Співавторів немає",
-    "Remove {collaboratorLabel} from the collaborators list" : "Видалити {collaboratorLabel} зі списку співавторів",
+    "No recommendations. Start typing." : "Відсутні рекомендації. Будь ласка, додайте.",
+    "Group" : "Група",
+    "Remove {collaboratorLabel} from the collaborators list" : "Вилучити {collaboratorLabel} зі списку співавторів",
     "Copy the public link" : "Копіювати публічне посилання",
     "Public link copied!" : "Публічне посилання скопійовано!",
     "Copy public link" : "Копіювати публічне посилання",
     "Delete the public link" : "Вилучити публічне посилання",
+    "Create public link share" : "Створити посилання спільного доступу",
     "Share via public link" : "Поділіться через публічне посилання",
     "Failed to fetch collaborators list." : "Не вдалося отримати список співавторів.",
-    "Failed to fetch album." : "Не вдалося отримати альбом.",
     "Failed to update album." : "Не вдалося оновити альбом.",
     "This collection does not exist" : "Ця колекція не існує",
     "An error occurred" : "Виникла помилка",
-    "_%n photos_::_%n photos_" : ["%n фото","%n фотографії","%n фотографії","%n фотографії"],
+    "_%n unassigned photo_::_%n unassigned photos_" : ["%n неідентифікована світлина","%n неідентифіковані світлини","%n неідентифікованих світлин","%n неідентифікованих світлин"],
+    "Favorite" : "До улюблених",
     "Select image {imageName}" : "Виберіть зображення {imageName}",
-    "The file is in the favorites" : "Файл знаходиться в обраному",
+    "Favorite image, open the full size \"{name}\" image" : "Вподобати зображення, відкрити повнорозмірне зображення: \"{name}\"",
     "Open the full size \"{name}\" image" : "Відкрити повнорозмірне зображення: \"{name}\"",
-    "There are no photos or videos yet!" : "Ще немає фото чи відео!",
-    "Add to {destination}" : "Додати до {destination}",
-    "Open the \"{name}\" sub-directory" : "Відкрити підкаталог \"{name}\"",
+    "Open the \"{name}\" folder" : "Відкрити каталог \"{name}\"",
+    "Go back" : "Повернутися назад",
     "Back to {folder}" : "Повернутися до каталогу {folder}",
     "Share this folder" : "Надати спільний доступ до каталогу",
+    "Dates" : "Дати",
+    "Jump to specific date in list" : "Перейти до певної дати зі списку",
+    "Jump to {date}" : "Перейти до {date}",
+    "Add to {destination}" : "Додати до {destination}",
+    "There are no photos or videos yet!" : "Ще немає фото чи відео!",
     "_{years} year ago_::_{years} years ago_" : ["{years} рік тому","{years} років тому","{years} років тому","{years} років тому"],
     "Enable squared photos view" : "Увімкнути перегляд фотографій у квадраті",
-    "Default Photos upload and Albums location" : "Розташування завантаження фотографій і альбомів за умовчанням",
-    "Select the default location for your media" : "Виберіть типове розташування для ваших зображень та відео",
-    "Invalid location selected" : "Вибрано недійсне місце розташування",
+    "Delete source directory" : "Вилучити каталог джерела",
+    "All folders" : "Усі каталоги",
+    "Choose a different folder" : "Виберіть інший каталог",
+    "Select a source folder for your media" : "Виберіть каталог джерела для ваших світлин чи відеозаписів",
+    "Home" : "Домівка",
+    "Choose default Photos upload and Albums location" : "Виберіть типове розташування для завантаження світлин та альбомів",
+    "Select the default upload location for your media" : "Виберіть типове розташування для завантаження ваших світлин чи відеозаписів",
     "View" : "Перегляд",
-    "Photos directory" : "Каталог фотографій",
+    "Media folder" : "Каталог для світлин чи відеозаписів",
+    "Choose the folders from where photos and videos are shown." : "Виберіть каталоги, з яких показувати світлини та відеозаписи.",
+    "Upload folder" : "Завантажити каталог",
+    "Choose the folder where photos and albums are uploaded to." : "Виберіть каталог, до якого завантажувати світлини та альбоми.",
     "_%n photo_::_%n photos_" : ["%n фото","%n фото","%n фото","%n фото"],
+    "Unselect all" : "Зняти вибір",
     "Manage collaborators for this album" : "Керуйте співавторами для цього альбому",
     "Open actions menu" : "Відкрити меню дій",
     "Edit album details" : "Редагувати деталі альбому",
-    "Download all files in album" : "Завантажити всі файли в альбомі",
-    "Delete album" : "Видалити альбом",
-    "Download selected files" : "Завантажте вибрані файли",
-    "Remove selection from album" : "Видалити виділення з альбому",
+    "Download all files in album" : "Звантажити всі файли в альбомі",
+    "Delete album" : "Вилучити альбом",
+    "Download selected files" : "Звантажити вибрані файли",
+    "Remove selection from album" : "Вилучити виділення з альбому",
     "This album does not have any photos or videos yet!" : "У цьому альбомі ще немає фото чи відео!",
     "Add photos to this album" : "Додайте фотографії до цього альбому",
-    "Add photos to the album" : "Додайте фотографії в альбом",
+    "Add photos to {albumName}" : "Додати світлини до {albumName}",
     "Manage collaborators" : "Керуйте співавторами",
     "Save collaborators for this album." : "Зберегти співавторів для цього альбому.",
     "Cover photo for album {albumName}" : "Обкладинка для альбому {albumName}",
-    "There is no album yet!" : "Альбому ще немає!",
+    "There is no album yet!" : "Альбоми поки відсутні",
     "This person could not be found" : "Цю людину не вдалося знайти",
     "Rename person" : "Перейменувати особу",
     "Merge with different person" : "Злитися з іншою людиною",
-    "Download selected photos" : "Завантажте вибрані фото",
-    "Favorite" : "До улюблених",
+    "Download selected photos" : "Звантажити вибрані світлини",
     "Remove from favorites" : "Вилучено з улюбленого",
-    "Remove person" : "Видалити особу",
+    "Remove person" : "Вилучити особу",
     "Name of this person" : "Ім'я цієї людини",
+    "Save." : "Зберегти.",
     "Merge person" : "Об’єднати особу",
-    "_Remove photo from person_::_Remove photos from person_" : ["Видалити фото з особи","Видалити фотографії з особи","Видалити фотографії з особи","Видалити фотографії з особи"],
+    "Move to different person" : "Перемістити до іншої особи",
+    "_Move photo to a different person_::_Move photos to a different person_" : ["Передати фотографії іншому користувачу","Передати фотографії іншим користувачам","Передати фотографії іншим користувачам","Передати фотографії іншим користувачам"],
+    "_Remove photo from person_::_Remove photos from person_" : ["Видалити фото з особи","Видалити фотографії з особи","Видалити фотографії з особи","Вилучити світлини особи"],
     "This might take some time depending on the size of your photo library." : "Це може зайняти деякий час залежно від розміру вашої бібліотеки фотографій.",
     "Recognized people will show up here" : "Тут відображатимуться розпізнані люди",
     "This folder does not exist" : "Цей каталог не існує",
     "Loading folders …" : "Завантаження папок…",
     "No photos in here" : "Тут немає світлин",
-    "Failed to fetch albums list." : "Не вдалося отримати список альбомів.",
-    "Shared albums" : "Альбоми із спільним доступом",
+    "Taken on {date} at {time}" : "Зроблено {date} о {time}",
+    "This place does not have any photos or videos yet!" : "У цього місця ще немає жодної фотографії чи відео!",
+    "Add photos to this place" : "Додайте фотографії до цього місця",
+    "Cover photo for place {placeName}" : "Обкладинка для місця {placeName}",
+    "There is no place yet!" : "Місця ще немає!",
     "Cover photo for shared album {albumName}." : "Обкладинка для спільного альбому {albumName}.",
-    "Back to tags overview" : "Назад до огляду тегів",
-    "No photos with this tag yet" : "Фотографій із цим тегом ще немає",
-    "No tags yet" : "Ще немає позначок",
-    "Photos with tags will show up here" : "Світлини з позначками буде показано тут",
-    "Popular tags" : "Популярні теги",
+    "Back to tags overview" : "Назад до огляду міток",
+    "No photos with this tag yet" : "Світлини з такою міткою відсутні",
+    "No tags yet" : "Ще немає міток",
+    "Photos with tags will show up here" : "Світлини з мітками буде показано тут",
+    "Popular tags" : "Популярні мітки",
+    "The source folder does not exists" : "Каталог джерела відсутній",
     "Add" : "Додати",
-    "Create a new album" : "Створіть новий альбом",
-    "Add selection to an album" : "Додайте виділене в альбом",
     "Add to album" : "Додати в альбом",
-    "Delete selection" : "Видалити виділення",
-    "Failed to fetch faces list." : "Не вдалося отримати список облич.",
+    "Delete selection" : "Вилучити виділення",
+    "No photos or videos in here" : "Тут немає фотографій та відео",
+    "Unassigned faces" : "Неідентифіковані обличчя",
+    "_%n photos_::_%n photos_" : ["%n фото","%n фотографії","%n фотографії","%n фотографії"],
+    "Failed to fetch collection." : "Не вдалося отримати колекцію.",
+    "Failed to fetch collections list." : "Не вдалося отримати список колекцій.",
+    "Failed to fetch faces list." : "Не вдалося отримати список зображень облич.",
     "All your media" : "Усі ваші зображення та відео",
-    "Tagged photos" : "Світлини з позначками",
-    "Failed to create {albumName}." : "Не вдалося створити {albumName}.",
-    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Не вдалося перейменувати {currentAlbumName} на {newAlbumName}.",
+    "Album {title}" : "Альбом {title}",
+    "Shared Albums" : "Спільні альбоми",
+    "Shared album {title}" : "Спільний альбом {title}",
+    "Public album {title}" : "Публічний альбом {title}",
+    "Tagged photos" : "Світлини з мітками",
+    "Tagged photo {title}" : "Світлина з міткою {title}",
+    "{title}'s face" : "обличчя {title}",
+    "{startDate} to {endDate}" : "{startDate} до {endDate}",
+    "Details" : "Деталі",
     "Failed to rename {oldName} to {faceName}." : "Не вдалося перейменувати {oldName} на {faceName}.",
-    "Failed to delete {faceName}." : "Не вдалося видалити {faceName}.",
-    "Failed to delete {fileId}." : "Не вдалося видалити {fileId}.",
-    "Failed to delete {fileName}." : "Не вдалося видалити {fileName}.",
+    "Failed to delete {faceName}." : "Не вдалося вилучити {faceName}.",
+    "Failed to delete {fileId}." : "Не вдалося вилучити {fileId}.",
+    "Failed to delete {fileName}." : "Не вдалося вилучити {fileName}.",
     "Failed to set favorite state for {fileId}." : "Не вдалося встановити улюблений стан для {fileId}.",
     "Failed to set favorite state for {fileName}." : "Не вдалося встановити улюблений стан для {fileName}.",
-    "Your photos" : "Ваші світлини",
-    "Your videos" : "Ваші відео",
-    "Your folders" : "Ваші каталоги",
-    "Settings" : "Налаштування"
+    "Could not load photos folder" : "Неможливо завантажити каталог зі світлинами",
+    "Go back to the previous view." : "Повернутися до попереднього перегляду.",
+    "Go to the add collaborators view." : "Перейдіть до перегляду додавання співавторів.",
+    "Create the album." : "Створіть альбом.",
+    "Back to the new album form." : "Повернутися до форми нового альбому.",
+    "_Share with %n user_::_Share with %n users_" : ["Поділіться з %n користувачем","Поділіться з %n користувачами","Поділіться з %n користувачами","Поділіться з %n користувачами"],
+    "Search for collaborators" : "Пошук співавторів",
+    "Add {collaboratorLabel} to the collaborators list" : "Додайте {collaboratorLabel} до списку співавторів",
+    "No collaborators available" : "Співавторів немає",
+    "Failed to fetch album." : "Не вдалося отримати альбом.",
+    "The file is in the favorites" : "Файл знаходиться в обраному",
+    "Open the \"{name}\" sub-directory" : "Відкрити підкаталог \"{name}\"",
+    "Default Photos upload and Albums location" : "Типове місце завантажених світлин та альбомів",
+    "Select the default location for your media" : "Виберіть типове розташування для ваших зображень та відео",
+    "Invalid location selected" : "Вибрано недійсне місце розташування",
+    "Photos directory" : "Каталог фотографій",
+    "Add photos to the album" : "Додайте фотографії в альбом",
+    "Failed to fetch albums list." : "Не вдалося отримати список альбомів.",
+    "Shared albums" : "Альбоми із спільним доступом",
+    "Create a new album" : "Створіть новий альбом",
+    "Add selection to an album" : "Додайте виділене в альбом",
+    "Failed to create {albumName}." : "Не вдалося створити {albumName}.",
+    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Не вдалося перейменувати {currentAlbumName} на {newAlbumName}."
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
