@@ -3,12 +3,11 @@ OC.L10N.register(
     {
     "Cannot write into \"config\" directory!" : "Impossible d’écrire dans le répertoire « config » !",
     "This can usually be fixed by giving the web server write access to the config directory." : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire de configuration.",
-    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ou, si vous préférez conserver le fichier config.php en lecture seule, définissez l'option \"config_is_read_only\" sur true.",
+    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ou, si vous préférez conserver le fichier config.php en lecture seule, définissez l'option « config_is_read_only » sur true.",
     "See %s" : "Voir %s",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Les fichiers de l'application %1$s n'ont pas été remplacés correctement. Veuillez vérifier que c'est une version compatible avec le serveur.",
-    "Sample configuration detected" : "Configuration d'exemple détectée",
+    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "L'application %1$s n'est pas présente ou n'est pas compatible avec cette version du serveur. Veuillez vérifier le répertoire des applications.",
+    "Sample configuration detected" : "Configuration d’exemple détectée",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Il a été détecté que la configuration donnée à titre d'exemple a été copiée. Cela peut rendre votre installation inopérante et n'est pas pris en charge. Veuillez lire la documentation avant d'effectuer des modifications dans config.php",
-    "404" : "404",
     "The page could not be found on the server." : "La page n'a pas pu être trouvée sur le serveur.",
     "%s email verification" : "Vérification de l'e-mail %s",
     "Email verification" : "Vérification de l'e-mail",
@@ -22,8 +21,8 @@ OC.L10N.register(
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s et %5$s",
     "Education Edition" : "Édition pour l'éducation ",
     "Enterprise bundle" : "Pack pour entreprise",
-    "Groupware bundle" : "Pack pour travail collaboratif",
-    "Hub bundle" : "Noyau de paquets",
+    "Groupware bundle" : "Pack Groupware",
+    "Hub bundle" : "Pack Nextcloud Hub",
     "Social sharing bundle" : "Pack pour partage social",
     "PHP %s or higher is required." : "PHP %s ou supérieur est requis.",
     "PHP with a version lower than %s is required." : "PHP avec une version antérieure à %s est requis.",
@@ -31,15 +30,15 @@ OC.L10N.register(
     "The following architectures are supported: %s" : "Les architectures suivantes sont prises en charge : %s",
     "The following databases are supported: %s" : "Les bases de données suivantes sont prises en charge : %s",
     "The command line tool %s could not be found" : "La commande %s est introuvable",
-    "The library %s is not available." : "La librairie %s n'est pas disponible.",
+    "The library %s is not available." : "La librairie %s n’est pas disponible.",
     "Library %1$s with a version higher than %2$s is required - available version %3$s." : "La librairie %1$s doit être au moins à la version %2$s. Version disponible : %3$s.",
     "Library %1$s with a version lower than %2$s is required - available version %3$s." : "La librairie %1$s doit avoir une version antérieure à %2$s. Version disponible : %3$s.",
     "The following platforms are supported: %s" : "Les plateformes suivantes sont prises en charge : %s",
     "Server version %s or higher is required." : "Un serveur de version %s ou supérieure est requis.",
     "Server version %s or lower is required." : "Un serveur de version %s ou inférieure est requis.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "L'utilisateur connecté doit être un administrateur, un sous-administrateur ou se voir accorder des droits spéciaux pour accéder à ce réglage",
-    "Logged in user must be an admin or sub admin" : "L'utilisateur connecté doit être administrateur ou sous-administrateur",
-    "Logged in user must be an admin" : "L'utilisateur connecté doit être un administrateur",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Le compte connecté doit être un administrateur, un sous-administrateur ou se voir accorder des droits spéciaux pour accéder à ce réglage",
+    "Logged in account must be an admin or sub admin" : "Le compte connecté doit être administrateur ou sous-administrateur",
+    "Logged in account must be an admin" : "Le compte connecté doit être un administrateur",
     "Wiping of device %s has started" : "L'effaçage de l'appareil %s a démarré",
     "Wiping of device »%s« has started" : "L'effaçage de l'appareil « %s » a démarré",
     "»%s« started remote wipe" : "« %s » a démarré l'effaçage distant",
@@ -54,10 +53,12 @@ OC.L10N.register(
     "The remote wipe on %s has finished" : "Le nettoyage à distance de %s est terminé",
     "Authentication" : "Authentification",
     "Unknown filetype" : "Type de fichier inconnu",
-    "Invalid image" : "Image non valable",
-    "Avatar image is not square" : "L'image d'avatar n'est pas carré",
+    "Invalid image" : "Image invalide",
+    "Avatar image is not square" : "L'image d'avatar n'est pas carrée",
+    "Files" : "Fichiers",
     "View profile" : "Voir le profil",
-    "today" : "aujourd'hui",
+    "Local time: %s" : "Heure locale : %s",
+    "today" : "aujourd’hui",
     "tomorrow" : "demain",
     "yesterday" : "hier",
     "_in %n day_::_in %n days_" : ["dans %n jour","dans %n jours","dans %n jours"],
@@ -67,7 +68,7 @@ OC.L10N.register(
     "_in %n month_::_in %n months_" : ["dans %n mois","dans %n mois","dans %n mois"],
     "_%n month ago_::_%n months ago_" : ["Il y a %n mois","Il y a %n mois","Il y a %n mois"],
     "next year" : "année suivante",
-    "last year" : "l'année dernière",
+    "last year" : "l’année dernière",
     "_in %n year_::_in %n years_" : ["dans %n an","dans %n ans","dans %n ans"],
     "_%n year ago_::_%n years ago_" : ["il y a %n an","il y a %n ans","il y a %n ans"],
     "_in %n hour_::_in %n hours_" : ["dans %n heure","dans %n heures","dans %n heures"],
@@ -83,12 +84,12 @@ OC.L10N.register(
     "Failed to create file from template" : "Impossible de créer le fichier à partir du modèle",
     "Templates" : "Modèles",
     "File name is a reserved word" : "Ce nom de fichier est un mot réservé",
-    "File name contains at least one invalid character" : "Le nom de fichier contient un (des) caractère(s) non valide(s)",
+    "File name contains at least one invalid character" : "Le nom de fichier contient au moins un caractère invalide",
     "File name is too long" : "Nom de fichier trop long",
     "Dot files are not allowed" : "Le nom de fichier ne peut pas commencer par un point",
-    "Empty filename is not allowed" : "Le nom de fichier ne peut pas être vide",
-    "App \"%s\" cannot be installed because appinfo file cannot be read." : "L'application \"%s\" ne peut pas être installée car le fichier appinfo ne peut pas être lu.",
-    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "L'application \"%s\" ne peut être installée car elle n'est pas compatible avec cette version du serveur",
+    "Empty filename is not allowed" : "Le nom de fichier n'est pas autorisé",
+    "App \"%s\" cannot be installed because appinfo file cannot be read." : "L'application « %s » ne peut pas être installée car le fichier appinfo ne peut pas être lu.",
+    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "L'application « %s » ne peut être installée car elle n'est pas compatible avec cette version du serveur.",
     "__language_name__" : "Français",
     "This is an automatically sent email, please do not reply." : "Ceci est un e-mail envoyé automatiquement, veuillez ne pas y répondre.",
     "Help" : "Aide",
@@ -101,6 +102,8 @@ OC.L10N.register(
     "Users" : "Utilisateurs",
     "Email" : "E-mail",
     "Mail %s" : "Courrier %s",
+    "Fediverse" : "Fediverse",
+    "View %s on the fediverse" : "Voir %s sur le Fediverse",
     "Phone" : "Téléphone",
     "Call %s" : "Appel %s",
     "Twitter" : "Twitter",
@@ -110,24 +113,26 @@ OC.L10N.register(
     "Address" : "Adresse",
     "Profile picture" : "Photo de profil",
     "About" : "À propos",
-    "Full name" : "Nom complet",
+    "Display name" : "Nom d'affichage",
     "Headline" : "Titre",
     "Organisation" : "Organisme",
     "Role" : "Fonction",
-    "Unknown user" : "Utilisateur inconnu",
+    "Unknown account" : "Compte inconnu",
     "Additional settings" : "Paramètres supplémentaires",
-    "Enter the database username and name for %s" : "Entrez le nom d'utilisateur et le nom de la base de données pour %s",
-    "Enter the database username for %s" : "Entrez le nom d'utilisateur de la base de données pour %s",
+    "Enter the database Login and name for %s" : "Saisissez l'identifiant et le nom de la base de données pour %s",
+    "Enter the database Login for %s" : "Saisissez l'identifiant de la base de données pour %s",
     "Enter the database name for %s" : "Entrez le nom de la base de données pour %s",
     "You cannot use dots in the database name %s" : "Vous ne pouvez pas utiliser de points dans le nom de la base de données %s",
-    "MySQL username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base MySQL non valide(s)",
+    "MySQL Login and/or password not valid" : "Identifiant et/ou mot de passe MySQL invalide",
     "You need to enter details of an existing account." : "Vous devez indiquer les détails d'un compte existant.",
     "Oracle connection could not be established" : "La connexion Oracle ne peut être établie",
-    "Oracle username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base Oracle non valide(s)",
-    "PostgreSQL username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base PostgreSQL non valide(s)",
+    "Oracle Login and/or password not valid" : "Identifiant et/ou mot de passe Oracle invalide",
+    "PostgreSQL Login and/or password not valid" : "Identifiant et/ou mot de passe PostgreSQL invalide",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X n'est pas pris en charge et %s ne fonctionnera pas correctement sur cette plate-forme. Son utilisation est à vos risques et périls !",
     "For the best results, please consider using a GNU/Linux server instead." : "Pour obtenir les meilleurs résultats, vous devriez utiliser un serveur GNU/Linux.",
-    "Set an admin username." : "Spécifiez un nom d'utilisateur pour l'administrateur.",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Il semble que cette instance %s fonctionne sur un environnement PHP 32 bits et open_basedir a été configuré dans php.ini. Cela engendre des problèmes avec les fichiers de taille supérieure à 4 Go et est donc fortement déconseillé.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Veuillez retirer la configuration open_basedir de votre php.ini ou utiliser une version PHP 64-bit.",
+    "Set an admin Login." : "Définissez un identifiant administrateur.",
     "Set an admin password." : "Spécifiez un mot de passe pour l'administrateur.",
     "Cannot create or write into the data directory %s" : "Impossible de créer ou d'écrire dans le répertoire des données %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Le service de partage %s doit implémenter l'interface OCP\\Share_Backend",
@@ -138,20 +143,21 @@ OC.L10N.register(
     "»%s« added a note to a file shared with you" : "%s a ajouté une note à un fichier partagé avec vous",
     "Open »%s«" : "Ouvrir « %s »",
     "%1$s via %2$s" : "%1$s via %2$s",
-    "You are not allowed to share %s" : "Vous n'êtes pas autorisé à partager %s",
+    "You are not allowed to share %s" : "Vous n’êtes pas autorisé à partager %s",
     "Cannot increase permissions of %s" : "Impossible d'augmenter les permissions de %s",
     "Files cannot be shared with delete permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de suppression",
     "Files cannot be shared with create permissions" : "Les fichiers ne peuvent pas être partagés avec les autorisations de création",
     "Expiration date is in the past" : "La date d'expiration est dans le passé",
-    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Impossible de définir la date d'expiration à dans plus de %s jour","Impossible de définir la date d'expiration à dans plus de %s jours","Impossible de définir la date d'expiration à dans plus de %s jours"],
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Impossible de définir la date d'expiration à dans plus de %n jour","Impossible de définir la date d'expiration à dans plus de %n jours","Impossible de définir la date d'expiration à dans plus de %n jours"],
     "Sharing is only allowed with group members" : "Le partage n'est que possible qu'avec les membres du groupe",
-    "Sharing %s failed, because this item is already shared with user %s" : "Impossible de partager %s car il est déjà partagé avec l'utilisateur %s",
+    "Sharing %s failed, because this item is already shared with the account %s" : "Impossible de partager %s car il est déjà partagé avec le compte %s",
     "%1$s shared »%2$s« with you" : "%1$s a partagé « %2$s » avec vous",
     "%1$s shared »%2$s« with you." : "%1$s a partagé « %2$s » avec vous.",
     "Click the button below to open it." : "Cliquez sur le bouton ci-dessous pour l'ouvrir",
     "The requested share does not exist anymore" : "Le partage demandé n'existe plus",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "La limite d'utilisateurs à été atteinte et cet utilisateur n'a pas été créé. Consultez vos notifications pour en savoir plus.",
-    "Could not find category \"%s\"" : "Impossible de trouver la catégorie \"%s\"",
+    "The requested share comes from a disabled user" : "Le partage demandé provient d'un utilisateur désactivé",
+    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "L'utilisateur n'a pas été créé car la limite du nombre d'utilisateurs a été atteinte. Consultez vos notifications pour en savoir plus.",
+    "Could not find category \"%s\"" : "Impossible de trouver la catégorie « %s »",
     "Sunday" : "Dimanche",
     "Monday" : "Lundi",
     "Tuesday" : "Mardi",
@@ -197,17 +203,17 @@ OC.L10N.register(
     "Oct." : "Oct.",
     "Nov." : "Nov.",
     "Dec." : "Déc.",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Seuls les caractères suivants sont autorisés dans un nom d'utilisateur : \"a-z\", \"A-Z\", \"0-9\", \"_@-\" et \".\" (le point)",
-    "A valid username must be provided" : "Un nom d'utilisateur valide doit être saisi",
-    "Username contains whitespace at the beginning or at the end" : "Le nom d'utilisateur contient des espaces au début ou à la fin",
-    "Username must not consist of dots only" : "Le nom d'utilisateur ne doit pas être composé uniquement de points",
-    "Username is invalid because files already exist for this user" : "Ce nom d'utilisateur n'est pas valide car des fichiers existent déjà pour cet utilisateur",
     "A valid password must be provided" : "Un mot de passe valide doit être saisi",
-    "The username is already being used" : "Ce nom d'utilisateur est déjà utilisé",
-    "Could not create user" : "Impossible de créer l'utilisateur",
-    "User disabled" : "Utilisateur désactivé",
-    "Login canceled by app" : "L'authentification a été annulé par l'application",
-    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "L'application \"%1$s\" ne peut pas être installée à cause des dépendances suivantes non satisfaites : %2$s",
+    "The Login is already being used" : "L'identifiant est déjà utilisé",
+    "Could not create account" : "Impossible de créer le compte",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Seuls les caractères suivants sont autorisés dans un identifiant : \"a-z\", \"A-Z\", \"0-9\", espaces et \"_.@-'\"",
+    "A valid Login must be provided" : "Un identifiant valide doit être saisi",
+    "Login contains whitespace at the beginning or at the end" : "L'identifiant contient des espaces au début ou à la fin",
+    "Login must not consist of dots only" : "L'identifiant ne doit pas être composé uniquement de points",
+    "Login is invalid because files already exist for this user" : "L’identifiant n'est pas valide car des fichiers existent déjà pour cet utilisateur",
+    "Account disabled" : "Compte désactivé",
+    "Login canceled by app" : "L'authentification a été annulée par l'application",
+    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "L'application « %1$s » ne peut pas être installée à cause des dépendances suivantes non satisfaites : %2$s",
     "a safe home for all your data" : "un lieu sûr pour toutes vos données",
     "File is currently busy, please try again later" : "Le fichier est actuellement utilisé, veuillez réessayer plus tard",
     "Cannot download file" : "Impossible de télécharger le fichier",
@@ -215,10 +221,10 @@ OC.L10N.register(
     "Authentication error" : "Erreur d'authentification",
     "Token expired. Please reload page." : "La session a expiré. Veuillez recharger la page.",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Aucun pilote de base de données n’est installé (sqlite, mysql ou postgresql).",
-    "Cannot write into \"config\" directory." : "Impossible d’écrire dans le répertoire \"config\".",
-    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire \"config\". Voir %s",
-    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ou, si vous préférez conserver le fichier config.php en lecture seule, définissez l'option \"config_is_read_only\" sur true. Voir %s",
-    "Cannot write into \"apps\" directory." : "Impossible d'écrire dans le répertoire \"apps\".",
+    "Cannot write into \"config\" directory." : "Impossible d’écrire dans le répertoire « config ».",
+    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire « config ». Voir %s",
+    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ou, si vous préférez conserver le fichier config.php en lecture seule, définissez l'option « config_is_read_only » sur true. Voir %s",
+    "Cannot write into \"apps\" directory." : "Impossible d'écrire dans le répertoire « apps ».",
     "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire des applications ou en désactivant le magasin d'applications dans le fichier de configuration.",
     "Cannot create \"data\" directory." : "Impossible de créer le dossier \"data\".",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire racine. Voir %s",
@@ -228,22 +234,18 @@ OC.L10N.register(
     "Please install one of these locales on your system and restart your web server." : "Veuillez installer l'un de ces paramètres régionaux sur votre système et redémarrer votre serveur web.",
     "PHP module %s not installed." : "Le module PHP %s n’est pas installé.",
     "Please ask your server administrator to install the module." : "Veuillez demander à votre administrateur d’installer le module.",
-    "PHP setting \"%s\" is not set to \"%s\"." : "Le paramètre PHP \"%s\" n'est pas \"%s\".",
+    "PHP setting \"%s\" is not set to \"%s\"." : "Le paramètre PHP « %s » n'est pas « %s ».",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Ajuster ce paramètre dans php.ini fera fonctionner Nextcould à nouveau",
     "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> est défini à <code>%s</code> alors que la valeur <code>0</code> est attendue.",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Pour corriger ce problème définissez <code>mbstring.func_overload</code> à <code>0</code> dans votre php.ini.",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 au moins est requis. Actuellement %s est installé.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Pour régler ce problème, mettez à jour votre version de libxml2 et redémarrez votre serveur web.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP semble configuré de manière à supprimer les blocs PHPdoc du code. Cela rendra plusieurs applications de base inaccessibles.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "La raison est probablement l'utilisation d'un cache / accélérateur tel que Zend OPcache ou eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "Les modules PHP ont été installés mais sont toujours indiqués comme manquants ?",
     "Please ask your server administrator to restart the web server." : "Veuillez demander à votre administrateur serveur de redémarrer le serveur web.",
     "The required %s config variable is not configured in the config.php file." : "La valeur de configuration requise %s n'est pas configurée dans votre fichier config.php.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Veuillez demander à votre administrateur serveur de vérifier la configuration de Nextcloud.",
-    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 requis.",
-    "Please upgrade your database version." : "Veuillez mettre à jour votre gestionnaire de base de données.",
-    "Your data directory is readable by other users." : "Votre répertoire est lisible par d'autres utilisateurs.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Veuillez changer les permissions du répertoire en mode 0770 afin que son contenu ne puisse pas être listé par les autres utilisateurs.",
+    "Your data directory is readable by other people." : "Votre répertoire de données est lisible par d'autres personnes.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Veuillez changer les permissions du répertoire en mode 0770 afin que son contenu ne puisse pas être listé par les autres personnes.",
     "Your data directory must be an absolute path." : "Le chemin de votre répertoire doit être un chemin absolu.",
     "Check the value of \"datadirectory\" in your configuration." : "Verifiez la valeur de \"datadirectory\" dans votre configuration.",
     "Your data directory is invalid." : "Votre répertoire des données n'est pas valide.",
@@ -251,39 +253,49 @@ OC.L10N.register(
     "Action \"%s\" not supported or implemented." : "Action \"%s\" non supportée ou implémentée.",
     "Authentication failed, wrong token or provider ID given" : "Échec de l'authentification, jeton erroné ou identification du fournisseur donnée",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Paramètres manquants pour compléter la requête. Paramètres manquants : \"%s\"",
-    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "L'identifiant \"%1$s\" est déjà utilisé par le fournisseur de cloud \"%2$s\"",
-    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Le fournisseur de cloud avec l'identifiant \"%s\" n'existe pas.",
-    "Could not obtain lock type %d on \"%s\"." : "Impossible d'obtenir le verrouillage de type %d sur \"%s\".",
+    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "L'identifiant \"%1$s\" est déjà utilisé par l'instance de Cloud Fédéré \"%2$s\"",
+    "Cloud Federation Provider with ID: \"%s\" does not exist." : "L'instance de Cloud Fédéré dont l'identifiant est \"%s\" n'existe pas.",
+    "Could not obtain lock type %d on \"%s\"." : "Impossible d'obtenir le verrouillage de type %d sur « %s ».",
     "Storage unauthorized. %s" : "Espace de stockage non autorisé. %s",
     "Storage incomplete configuration. %s" : "Configuration de l'espace de stockage incomplète. %s",
     "Storage connection error. %s" : "Erreur de connexion à l'espace stockage. %s",
     "Storage is temporarily not available" : "Le support de stockage est temporairement indisponible",
     "Storage connection timeout. %s" : "Le délai d'attente pour la connexion à l'espace de stockage a été dépassé. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire de configuration.",
-    "%s enter the database username and name." : "%s entrez le nom d'utilisateur et le nom de la base de données.",
-    "%s enter the database username." : "%s entrez le nom d'utilisateur de la base de données.",
-    "%s enter the database name." : "%s entrez le nom de la base de données.",
-    "%s you may not use dots in the database name" : "%s vous ne pouvez pas utiliser de points dans le nom de la base de données",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Il semble que cette instance %s fonctionne sur un environnement PHP 32-bit et open_basedir a été configuré dans php.ini. Cela engendre des problèmes avec les fichiers de taille supérieure à 4 Go et est donc fortement déconseillé.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Veuillez supprimer la configuration open_basedir de votre php.ini ou utiliser une version PHP 64-bit.",
-    "The user limit has been reached and the user was not created." : "Le nombre maximum d'utilisateurs a été atteint, l'utilisateur n'a pas pu être créé.",
-    "Cannot read file" : "Impossible de lire le fichier",
-    "Cannot write into \"config\" directory" : "Impossible d’écrire dans le répertoire \"config\"",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire \"config\". Voir %s",
-    "Cannot write into \"apps\" directory" : "Impossible d’écrire dans le répertoire \"apps\"",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire des applications ou en désactivant le magasin d'applications dans le fichier de configuration.",
-    "Cannot create \"data\" directory" : "Impossible de créer le dossier \"data\"",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Ce problème est généralement résolu en donnant au serveur web un accès en écriture au répertoire racine. Voir %s",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Le problème de permissions peut généralement être résolu en donnant au serveur web un accès en écriture au répertoire racine. Voir %s.",
-    "Setting locale to %s failed" : "Echec de la spécification des paramètres régionaux à %s",
-    "Please install one of these locales on your system and restart your webserver." : "Veuillez installer l'un de ces paramètres régionaux sur votre système et redémarrer votre serveur web.",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload est à \"%s\" alors que la valeur \"0\" est attendue",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Pour corriger ce problème mettez <code>mbstring.func_overload</code> à <code>0</code> dans votre php.ini",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 requis",
-    "Please upgrade your database version" : "Veuillez mettre à jour votre gestionnaire de base de données",
-    "Your data directory is readable by other users" : "Votre répertoire est lisible par les autres utilisateurs",
-    "Your data directory must be an absolute path" : "Le chemin de votre répertoire doit être un lien absolu",
-    "Check the value of \"datadirectory\" in your configuration" : "Verifiez la valeur de \"datadirectory\" dans votre configuration",
-    "Your data directory is invalid" : "Votre répertoire n'est pas valide"
+    "Free prompt" : "Prompt",
+    "Runs an arbitrary prompt through the language model." : "Exécute une commande arbitraire via le modèle de langage.",
+    "Generate headline" : "Générer un titre",
+    "Generates a possible headline for a text." : "Génère un titre possible pour un texte.",
+    "Summarize" : "Résumer",
+    "Summarizes text by reducing its length without losing key information." : "Résume un texte en réduisant sa longueur sans perdre d'informations essentielles.",
+    "Extract topics" : "Extraire des thèmes",
+    "Extracts topics from a text and outputs them separated by commas." : "Extrait les thèmes d'un texte et les restitue séparés par des virgules.",
+    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Les fichiers de l'application %1$s n'ont pas été remplacés correctement. Veuillez vérifier que c'est une version compatible avec le serveur.",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "L'utilisateur connecté doit être un administrateur, un sous-administrateur ou se voir accorder des droits spéciaux pour accéder à ce réglage",
+    "Logged in user must be an admin or sub admin" : "L'utilisateur connecté doit être administrateur ou sous-administrateur",
+    "Logged in user must be an admin" : "L'utilisateur connecté doit être un administrateur",
+    "Full name" : "Nom complet",
+    "Unknown user" : "Utilisateur inconnu",
+    "Enter the database username and name for %s" : "Entrez le nom d'utilisateur et le nom de la base de données pour %s",
+    "Enter the database username for %s" : "Entrez le nom d'utilisateur de la base de données pour %s",
+    "MySQL username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base MySQL non valide(s)",
+    "Oracle username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base Oracle non valide(s)",
+    "PostgreSQL username and/or password not valid" : "Nom d'utilisateur et/ou mot de passe de la base PostgreSQL non valide(s)",
+    "Set an admin username." : "Spécifiez un nom d'utilisateur pour l'administrateur.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Impossible de partager %s car il est déjà partagé avec l'utilisateur %s",
+    "The username is already being used" : "Ce nom d'utilisateur est déjà utilisé",
+    "Could not create user" : "Impossible de créer l'utilisateur",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Seuls les caractères suivants sont autorisés dans un nom d'utilisateur : \"a-z\", \"A-Z\", \"0-9\", espaces et \"_.@-'\"",
+    "A valid username must be provided" : "Un nom d'utilisateur valide doit être saisi",
+    "Username contains whitespace at the beginning or at the end" : "Le nom d'utilisateur contient des espaces au début ou à la fin",
+    "Username must not consist of dots only" : "Le nom d'utilisateur ne doit pas être composé uniquement de points",
+    "Username is invalid because files already exist for this user" : "Ce nom d'utilisateur n'est pas valide car des fichiers existent déjà pour cet utilisateur",
+    "User disabled" : "Utilisateur désactivé",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 au moins est requis. Actuellement %s est installé.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Pour régler ce problème, mettez à jour votre version de libxml2 et redémarrez votre serveur web.",
+    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 requis.",
+    "Please upgrade your database version." : "Veuillez mettre à jour votre gestionnaire de base de données.",
+    "Your data directory is readable by other users." : "Votre répertoire est lisible par d'autres utilisateurs.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Veuillez changer les permissions du répertoire en mode 0770 afin que son contenu ne puisse pas être listé par les autres utilisateurs."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
