@@ -2,13 +2,12 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "\"config\" klasörüne yazılamadı!",
-    "This can usually be fixed by giving the web server write access to the config directory." : "Bu sorun genellikle, web sunucusuna config klasörüne yazma izni verilerek çözülebilir.",
+    "This can usually be fixed by giving the web server write access to the config directory." : "Bu sorun genellikle, site sunucusuna config klasörüne yazma izni verilerek çözülebilir.",
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Ama config.php dosyasının salt okunur olarak kalmasını istiyorsanız içindeki \"config_is_read_only\" seçeneğini true olarak ayarlayın.",
     "See %s" : "Şuraya bakın: %s",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "%1$s uygulamasının dosyaları doğru şekilde değiştirilmedi. Sunucu ile uyumlu dosyaların yüklü olduğundan emin olun.",
+    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "%1$s uygulaması yok ya da bu sunucuyla uyumlu olmayan bir sürümü var. Lütfen apps klasörünü kontrol edin.",
     "Sample configuration detected" : "Örnek yapılandırma algılandı",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Örnek yapılandırmanın kopyalanmış olabileceği tespit edildi. Bu durum kurulumunuzu bozabilir ve desteklenmez. Lütfen config.php dosyasında değişiklik yapmadan önce belgeleri okuyun",
-    "404" : "404",
     "The page could not be found on the server." : "Sayfa sunucuda bulunamadı.",
     "%s email verification" : "%s e-posta doğrulaması",
     "Email verification" : "E-posta doğrulaması",
@@ -24,12 +23,13 @@ OC.L10N.register(
     "Enterprise bundle" : "Kurumsal paket",
     "Groupware bundle" : "Grup çalışması paketi",
     "Hub bundle" : "Toplayıcı paketi",
+    "Public sector bundle" : "Kamu sektörü paketi",
     "Social sharing bundle" : "Sosyal ağ paketi",
     "PHP %s or higher is required." : "PHP %s ya da daha sonraki bir sürümü gerekli.",
     "PHP with a version lower than %s is required." : "PHP %s ya da daha önceki bir sürümü gerekli.",
     "%sbit or higher PHP required." : "%sbit ya da daha sonraki bir PHP sürümü gerekli.",
     "The following architectures are supported: %s" : "Şu mimariler destekleniyor: %s",
-    "The following databases are supported: %s" : "Şu veritabanları destekleniyor: %s",
+    "The following databases are supported: %s" : "Şu veri tabanları destekleniyor: %s",
     "The command line tool %s could not be found" : "%s komut satırı aracı bulunamadı",
     "The library %s is not available." : "%s kitaplığı bulunamadı.",
     "Library %1$s with a version higher than %2$s is required - available version %3$s." : "%1$s kitaplığının %2$s sonrası bir sürümü gerekli. Geçerli sürüm: %3$s.",
@@ -37,9 +37,9 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Şu platformlar destekleniyor: %s",
     "Server version %s or higher is required." : "Sunucu %s ya da daha sonraki bir sürüm olmalıdır.",
     "Server version %s or lower is required." : "Sunucu %s ya da daha önceki bir sürüm olmalıdır.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Oturum açmış kullanıcı bir yönetici, bir alt yönetici veya bu ayara erişmek için özel izne sahip olmalıdır",
-    "Logged in user must be an admin or sub admin" : "Oturum açmış kullanıcı bir yönetici ya da alt yönetici olmalıdır",
-    "Logged in user must be an admin" : "Oturum açmış kullanıcı bir yönetici olmalıdır",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Oturum açmış hesap bir yönetici, bir alt yönetici veya bu ayara erişmek için özel izne sahip olmalıdır",
+    "Logged in account must be an admin or sub admin" : "Oturum açmış hesap bir yönetici ya da alt yönetici olmalıdır",
+    "Logged in account must be an admin" : "Oturum açmış hesap bir yönetici olmalıdır",
     "Wiping of device %s has started" : "%s aygıtının silinmesine başlandı",
     "Wiping of device »%s« has started" : "»%s« aygıtının silinmesine başlandı",
     "»%s« started remote wipe" : "»%s« uzaktan silme işlemi başladı",
@@ -56,18 +56,20 @@ OC.L10N.register(
     "Unknown filetype" : "Dosya türü bilinmiyor",
     "Invalid image" : "Görsel geçersiz",
     "Avatar image is not square" : "Avatar görseli kare değil",
+    "Files" : "Dosyalar",
     "View profile" : "Profili görüntüle",
+    "Local time: %s" : "Yerel zaman: %s",
     "today" : "bugün",
     "tomorrow" : "yarın",
     "yesterday" : "dün",
     "_in %n day_::_in %n days_" : ["%n gün içinde","%n gün içinde"],
     "_%n day ago_::_%n days ago_" : ["%n gün önce","%n gün önce"],
-    "next month" : "gelecek ay",
-    "last month" : "geçen ay",
+    "next month" : "sonraki ay",
+    "last month" : "önceki ay",
     "_in %n month_::_in %n months_" : ["%n ay içinde","%n ay içinde"],
     "_%n month ago_::_%n months ago_" : ["%n ay önce","%n ay önce"],
-    "next year" : "gelecek yıl",
-    "last year" : "geçen yıl",
+    "next year" : "sonraki yıl",
+    "last year" : "önceki yıl",
     "_in %n year_::_in %n years_" : ["%n yıl içinde","%n yıl içinde"],
     "_%n year ago_::_%n years ago_" : ["%n yıl önce","%n yıl önce"],
     "_in %n hour_::_in %n hours_" : ["%n saat içinde","%n saat içinde"],
@@ -77,7 +79,7 @@ OC.L10N.register(
     "in a few seconds" : "bir kaç saniye içinde",
     "seconds ago" : "saniyeler önce",
     "Empty file" : "Dosya boş",
-    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "%s kodlu modül bulunamadı. Lütfen uygulamalarınız içinden modülü etkinleştirin ya da BT yöneticinizle görüşün.",
+    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "%s kimlikli modül bulunamadı. Lütfen uygulamalarınız içinden modülü etkinleştirin ya da BT yöneticinizle görüşün.",
     "File already exists" : "Dosya zaten var",
     "Invalid path" : "Yol geçersiz",
     "Failed to create file from template" : "Kalıptan dosya oluşturulamadı",
@@ -101,33 +103,37 @@ OC.L10N.register(
     "Users" : "Kullanıcılar",
     "Email" : "E-posta",
     "Mail %s" : "E-posta gönder: %s",
+    "Fediverse" : "Fediverse",
+    "View %s on the fediverse" : "%s Fediverse üzerinde görüntülensin",
     "Phone" : "Telefon",
     "Call %s" : "Çağrı gönder: %s",
     "Twitter" : "Twitter",
     "View %s on Twitter" : "Twitter üzerinde bak: %s",
-    "Website" : "Web sitesi",
-    "Visit %s" : "Web sitesini aç: %s",
+    "Website" : "Site",
+    "Visit %s" : "Siteyi aç: %s",
     "Address" : "Adres",
     "Profile picture" : "Profil görseli",
     "About" : "Hakkında",
-    "Full name" : "Tam ad",
+    "Display name" : "Görüntülenecek ad",
     "Headline" : "Başlık",
     "Organisation" : "Kuruluş",
     "Role" : "Pozisyon",
-    "Unknown user" : "Kullanıcı bilinmiyor",
+    "Unknown account" : "Hesap bilinmiyor",
     "Additional settings" : "Ek ayarlar",
-    "Enter the database username and name for %s" : "%s için veritabanı adını ve kullanıcı adını yazın",
-    "Enter the database username for %s" : "%s için veritabanı kullanıcı adını yazın",
-    "Enter the database name for %s" : "%s için veritabanı adını yazın",
-    "You cannot use dots in the database name %s" : "%s veritabanı adında nokta kullanamazsınız",
-    "MySQL username and/or password not valid" : "MySQL kullanıcı adı ya da parolası geçersiz",
+    "Enter the database Login and name for %s" : "%s için veri tabanı adını ve kullanıcı adını yazın",
+    "Enter the database Login for %s" : "%s için veri tabanı kullanıcı adını yazın",
+    "Enter the database name for %s" : "%s için veri tabanı adını yazın",
+    "You cannot use dots in the database name %s" : "%s veri tabanı adında nokta kullanamazsınız",
+    "MySQL Login and/or password not valid" : "MySQL kullanıcı adı ve/veya parolası geçersiz",
     "You need to enter details of an existing account." : "Var olan bir hesabın bilgilerini yazmalısınız.",
     "Oracle connection could not be established" : "Oracle ile bağlantı kurulamadı",
-    "Oracle username and/or password not valid" : "Oracle kullanıcı adı ya da parolası geçersiz",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL kullanıcı adı ya da parolası geçersiz",
+    "Oracle Login and/or password not valid" : "Oracle kullanıcı adı ve/veya parolası geçersiz",
+    "PostgreSQL Login and/or password not valid" : "PostgreSQL kullanıcı adı ve/veya parolası geçersiz",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X desteklenmiyor ve %s bu platformda düzgün çalışmayacak. Kullanmaktan doğacak riskler size aittir!",
     "For the best results, please consider using a GNU/Linux server instead." : "En iyi sonucu almak için GNU/Linux sunucusu kullanın.",
-    "Set an admin username." : "Bir yönetici kullanıcı adı yazın.",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Bu %s kopyası 32 bit PHP ortamında çalıştırılıyor ve open_basedir seçeneği php.ini dosyasından ayarlanmış gibi görünüyor. Bu yapılandırma 4 GB boyutundan büyük dosyalarda sorun çıkarır ve kullanılması önerilmez.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Lütfen php.ini dosyasındaki open_basedir ayarını kaldırın ya da 64-bit PHP sürümüne geçin.",
+    "Set an admin Login." : "Bir yönetici kullanıcı adı yazın.",
     "Set an admin password." : "Bir yönetici parolası yazın.",
     "Cannot create or write into the data directory %s" : "%s veri klasörü oluşturulamadı ya da içine yazılamadı",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Paylaşım arka ucu %s OCP\\Share_Backend arayüzünü desteklemeli",
@@ -142,15 +148,16 @@ OC.L10N.register(
     "Cannot increase permissions of %s" : "%s izinleri yükseltilemedi",
     "Files cannot be shared with delete permissions" : "Silme izni ile dosya paylaşılamaz",
     "Files cannot be shared with create permissions" : "Ekleme izni ile dosya paylaşılamaz",
-    "Expiration date is in the past" : "Son kullanma tarihi geçmişte",
-    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Paylaşımların son kullanım süreleri, gelecekte %n günden fazla olamaz","Paylaşımların son kullanım süreleri, gelecekte %n günden fazla olamaz"],
+    "Expiration date is in the past" : "Geçerlilik sonu tarihi geçmişte",
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Paylaşımların geçerlilik süreleri, gelecekte %n günden fazla olamaz","Paylaşımların geçerlilik süreleri, gelecekte %n günden fazla olamaz"],
     "Sharing is only allowed with group members" : "Paylaşım yalnızca grup üyeleri ile yapılabilir",
-    "Sharing %s failed, because this item is already shared with user %s" : "%s paylaşılamadı. Bu öge zaten %s kullanıcısı ile paylaşılmış",
+    "Sharing %s failed, because this item is already shared with the account %s" : "%s paylaşılamadı. Bu öge zaten %s hesabı ile paylaşılmış",
     "%1$s shared »%2$s« with you" : "%1$s, sizinle »%2$s« ögesini paylaştı",
     "%1$s shared »%2$s« with you." : "%1$s, sizinle »%2$s« ögesini paylaştı.",
     "Click the button below to open it." : "Açmak için aşağıdaki düğmeye tıklayın.",
     "The requested share does not exist anymore" : "Erişilmek istenilen paylaşım artık yok",
-    "The user limit has been reached and the user was not created. Check your notifications to learn more." : "Kullanıcı sayısı sınırına ulaşıldığından kullanıcı eklenemedi. Ayrıntılı bilgi almak için bildirimlerinize bakın.",
+    "The requested share comes from a disabled user" : "Erişilmek istenilen paylaşım devre dışı bırakılmış bir kullanıcıdan geliyor",
+    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Kullanıcı sayısı sınırına ulaşıldığından kullanıcı eklenemedi. Ayrıntılı bilgi almak için bildirimlerinize bakın.",
     "Could not find category \"%s\"" : "\"%s\" kategorisi bulunamadı",
     "Sunday" : "Pazar",
     "Monday" : "Pazartesi",
@@ -197,15 +204,15 @@ OC.L10N.register(
     "Oct." : "Eki",
     "Nov." : "Kas",
     "Dec." : "Ara",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Kullanıcı adında yalnızca şu karakterler kullanılabilir: \"a-z\", \"A-Z\", \"0-9\", ve \"_.@-'\"",
-    "A valid username must be provided" : "Geçerli bir kullanıcı adı yazmalısınız",
-    "Username contains whitespace at the beginning or at the end" : "Kullanıcı adının başı ya da sonunda boşluk var",
-    "Username must not consist of dots only" : "Kullanıcı adı yalnızca noktalardan oluşamaz",
-    "Username is invalid because files already exist for this user" : "Kullanıcı adı geçersiz, bu kullanıcı için zaten bazı dosyalar var",
     "A valid password must be provided" : "Geçerli bir parola yazmalısınız",
-    "The username is already being used" : "Bu kullanıcı adı zaten var",
-    "Could not create user" : "Kullanıcı oluşturulamadı",
-    "User disabled" : "Kullanıcı devre dışı",
+    "The Login is already being used" : "Bu kullanıcı adı zaten var",
+    "Could not create account" : "Hesap oluşturulamadı",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Kullanıcı adında yalnızca şu karakterler kullanılabilir: \"a-z\", \"A-Z\", \"0-9\", boşluk ve \"_.@-'\"",
+    "A valid Login must be provided" : "Geçerli bir kullanıcı adı yazmalısınız",
+    "Login contains whitespace at the beginning or at the end" : "Kullanıcı adının başında ya da sonunda boşluk var",
+    "Login must not consist of dots only" : "Kullanıcı adı yalnızca noktalardan oluşamaz",
+    "Login is invalid because files already exist for this user" : "Kullanıcı adı geçersiz, bu kullanıcı için zaten bazı dosyalar var",
+    "Account disabled" : "Hesap devre dışı",
     "Login canceled by app" : "Oturum açma uygulama tarafından iptal edildi",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "\"%1$s\" uygulaması, şu gereklilikler sağlanmadığı için kurulamıyor: %2$s",
     "a safe home for all your data" : "verileriniz için güvenli bir barınak",
@@ -214,76 +221,82 @@ OC.L10N.register(
     "Application is not enabled" : "Uygulama etkinleştirilmemiş",
     "Authentication error" : "Kimlik doğrulama sorunu",
     "Token expired. Please reload page." : "Kodun geçerlilik süresi dolmuş. Lütfen sayfayı yenileyin.",
-    "No database drivers (sqlite, mysql, or postgresql) installed." : "Herhangi bir veritabanı sürücüsü (sqlite, mysql ya da postgresql) kurulmamış.",
+    "No database drivers (sqlite, mysql, or postgresql) installed." : "Herhangi bir veri tabanı sürücüsü (sqlite, mysql ya da postgresql) kurulmamış.",
     "Cannot write into \"config\" directory." : "\"config\" klasörüne yazılamadı.",
-    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Bu sorun genellikle, web sunucusuna config klasörüne yazma izni verilerek çözülebilir. %s bölümüne bakın",
+    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Bu sorun genellikle, site sunucusuna config klasörüne yazma izni verilerek çözülebilir. %s bölümüne bakın",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Ya da config.php dosyasının salt okunur olarak kalmasını istiyorsanız içindeki \"config_is_read_only\" seçeneğini true olarak ayarlayın. %s bölümüne bakabilirsiniz",
     "Cannot write into \"apps\" directory." : "\"apps\" klasörüne yazılamadı.",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Bu sorun genellikle, web sunucusuna apps klasörüne yazma izni verilerek ya da yapılandırma dosyasından Uygulama Mağazası devre dışı bırakılarak çözülebilir.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Bu sorun genellikle, site sunucusuna apps klasörüne yazma izni verilerek ya da yapılandırma dosyasından uygulama mağazası devre dışı bırakılarak çözülebilir.",
     "Cannot create \"data\" directory." : "\"data\" klasörü oluşturulamadı",
-    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Bu sorun genellikle, web sunucusuna kök klasöre yazma izni verilerek çözülebilir. %s bölümüne bakın",
-    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "İzinler genellikle, web sunucusuna kök klasöre yazma izni verilerek düzeltilebilir. %s bölümüne bakın.",
+    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Bu sorun genellikle, site sunucusuna kök klasöre yazma izni verilerek çözülebilir. %s bölümüne bakın",
+    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "İzinler genellikle, site sunucusuna kök klasöre yazma izni verilerek düzeltilebilir. %s bölümüne bakın.",
     "Your data directory is not writable." : "Veri klasörünüz yazılabilir değil.",
     "Setting locale to %s failed." : "Dil %s olarak ayarlanamadı.",
-    "Please install one of these locales on your system and restart your web server." : "Lütfen bu dillerden birini sisteminize kurun ve web sunucunuzu yeniden başlatın.",
+    "Please install one of these locales on your system and restart your web server." : "Lütfen bu dillerden birini sisteminize kurun ve site sunucunuzu yeniden başlatın.",
     "PHP module %s not installed." : "PHP %s modülü kurulmamış.",
     "Please ask your server administrator to install the module." : "Lütfen modülü kurması için BT yöneticinizle görüşün.",
     "PHP setting \"%s\" is not set to \"%s\"." : "\"%s\" PHP ayarı \"%s\" olarak ayarlanmamış.",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "php.ini dosyasında bu ayar yapıldığında Nextcloud yeniden çalışır",
     "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code>, beklenen <code>0</code> değeri yerine <code>%s</code> olarak ayarlanmış.",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Bu sorunu çözmek için php.ini dosyasındaki <code>mbstring.func_overload</code> seçeneğini <code>0</code> olarak ayarlayın.",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 sürümü en az 2.7.0 olmalıdır. Şu anda %s kurulu.",
-    "To fix this issue update your libxml2 version and restart your web server." : "Bu sorunu çözmek için libxml2 sürümünüzü güncelleyin ve web sunucusunu yeniden başlatın.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP girintili doc bloklarını ayıklamak üzere yapılandırılmış gibi görünüyor. Bu durum bazı çekirdek uygulamalarına erişilmesini engelleyecek.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Bu sorun genellikle Zend OPcache ya da eAccelerator gibi bir ön bellek/hızlandırıcı nedeniyle ortaya çıkar.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP modülleri kurulmuş, ancak hala eksik olarak mı görünüyor?",
-    "Please ask your server administrator to restart the web server." : "Lütfen web sunucusunu yeniden başlatması için BT yöneticinizle görüşün.",
+    "Please ask your server administrator to restart the web server." : "Lütfen site sunucusunu yeniden başlatması için BT yöneticinizle görüşün.",
     "The required %s config variable is not configured in the config.php file." : "Gereken %s yapılandırma değişkeni config.php dosyasında ayarlanmamış.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Lütfen Nextcloud yapılandırmasını denetlemesi için BT yöneticinizle görüşün.",
-    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 gerekli.",
-    "Please upgrade your database version." : "Lütfen veritabanı sürümünüzü yükseltin.",
-    "Your data directory is readable by other users." : "Veri klasörünüz diğer kullanıcılar tarafından okunabilir.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Lütfen izinleri 0770 olarak ayarlayarak diğer kullanıcıların klasörü görebilmesini sağlayın.",
+    "Your data directory is readable by other people." : "Veri klasörünüz diğer kişiler tarafından okunabilir.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Lütfen izinleri 0770 olarak ayarlayarak diğer kişilerin klasörü görebilmesini sağlayın.",
     "Your data directory must be an absolute path." : "Veri klasörünüz mutlak bir yol olmalıdır.",
     "Check the value of \"datadirectory\" in your configuration." : "Yapılandırmanızdaki \"datadirectory\" değerini denetleyin.",
     "Your data directory is invalid." : "Veri klasörünüz geçersiz.",
     "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Veri klasörü kökünde \".ocdata\" adında bir dosya bulunduğundan emin olun.",
     "Action \"%s\" not supported or implemented." : "\"%s\" işlemi desteklenmiyor ya da henüz kullanılamıyor.",
-    "Authentication failed, wrong token or provider ID given" : "Kimlik doğrulanamadı. Belirtilen kod ya da hizmet sağlayıcı kodu hatalı",
+    "Authentication failed, wrong token or provider ID given" : "Kimlik doğrulanamadı. Belirtilen kod ya da hizmet sağlayıcı kimliği hatalı",
     "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "İsteğin tamamlanması için gerekli parametreler eksik: \"%s\"",
-    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "\"%1$s\" kodu zaten \"%2$s\" birleşik hizmet sağlayıcısı tarafından kullanılıyor",
-    "Cloud Federation Provider with ID: \"%s\" does not exist." : "\"%s\" kodlu birleşik bulut hizmeti sağlayıcısı bulunamadı.",
+    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "\"%1$s\" kimliği zaten \"%2$s\" birleşik hizmet sağlayıcısı tarafından kullanılıyor",
+    "Cloud Federation Provider with ID: \"%s\" does not exist." : "\"%s\" kimlikli birleşik bulut hizmeti sağlayıcısı bulunamadı.",
     "Could not obtain lock type %d on \"%s\"." : "\"%s\" için %d kilit türü alınamadı.",
     "Storage unauthorized. %s" : "Depolamaya erişim izni yok. %s",
     "Storage incomplete configuration. %s" : "Depolama yapılandırması tamamlanmamış. %s",
     "Storage connection error. %s" : "Depolama bağlantısı sorunu. %s",
     "Storage is temporarily not available" : "Depolama geçici olarak kullanılamıyor",
     "Storage connection timeout. %s" : "Depolama bağlantısı zaman aşımı. %s",
-    "This can usually be fixed by giving the webserver write access to the config directory." : "Bu sorun genellikle, web sunucusuna config klasörüne yazma izni verilerek çözülebilir.",
-    "%s enter the database username and name." : "%s veritabanı adını ve kullanıcı adını yazın.",
-    "%s enter the database username." : "%s veritabanı kullanıcı adını yazın.",
-    "%s enter the database name." : "%s veritabanı adını yazın.",
-    "%s you may not use dots in the database name" : "%s veritabanı adında nokta kullanamayabilirsiniz",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Bu %s kopyası 32 bit PHP ortamında çalıştırılıyor ve open_basedir seçeneği php.ini dosyasından ayarlanmış gibi görünüyor. Bu yapılandırma 4 GB boyutundan büyük dosyalarda sorun çıkarır ve kullanılması önerilmez.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Lütfen php.ini dosyasındaki open_basedir ayarını kaldırın ya da 64-bit PHP sürümüne geçin.",
-    "The user limit has been reached and the user was not created." : "Kullanıcı sayısı sınırına ulaşıldığından kullanıcı eklenemedi.",
-    "Cannot read file" : "Dosya okunamadı",
-    "Cannot write into \"config\" directory" : "\"config\" klasörüne yazılamıyor",
-    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "Bu sorun genellikle, web sunucusuna config klasörüne yazma izni verilerek çözülebilir. %s bölümüne bakın",
-    "Cannot write into \"apps\" directory" : "\"apps\" klasörüne yazılamıyor",
-    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the App Store in the config file." : "Bu sorun genellikle, web sunucusuna apps klasörüne yazma izni verilerek ya da yapılandırma dosyasından Uygulama Mağazası devre dışı bırakılarak çözülebilir.",
-    "Cannot create \"data\" directory" : "\"data\" klasörü oluşturulamadı",
-    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "Bu sorun genellikle, web sunucusuna kök klasöre yazma izni verilerek çözülebilir. %s bölümüne bakın",
-    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "İzinler genellikle, web sunucusuna kök klasöre yazma izni verilerek düzeltilebilir. %s bölümüne bakın.",
-    "Setting locale to %s failed" : "Dil %s olarak ayarlanamadı",
-    "Please install one of these locales on your system and restart your webserver." : "Lütfen bu dillerden birini sisteminize kurun ve web sunucunuzu yeniden başlatın.",
-    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload, beklenen \"0\" değeri yerine \"%s\" olarak ayarlanmış",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Bu sorunu çözmek için php.ini dosyasındaki <code>mbstring.func_overload</code> seçeneğini <code>0</code> olarak ayarlayın",
-    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 gerekli",
-    "Please upgrade your database version" : "Lütfen veritabanı sürümünüzü yükseltin",
-    "Your data directory is readable by other users" : "Veri klasörünüz diğer kullanıcılar tarafından okunabilir",
-    "Your data directory must be an absolute path" : "Veri klasörünüz mutlak bir yol olmalıdır",
-    "Check the value of \"datadirectory\" in your configuration" : "Yapılandırmanızdaki \"datadirectory\" seçeneğini denetleyin",
-    "Your data directory is invalid" : "Veri klasörünüz geçersiz"
+    "Free prompt" : "Ücretsiz bilgi istemi",
+    "Runs an arbitrary prompt through the language model." : "Dil modeli ile isteğe bağlı bir bilgi istemi çalıştırır.",
+    "Generate headline" : "Başlık oluşturulsun",
+    "Generates a possible headline for a text." : "Bir metin için olası bir başlık oluşturur.",
+    "Summarize" : "Özetlensin",
+    "Summarizes text by reducing its length without losing key information." : "Temel içeriği kaybetmeden uzunluğunu kısaltarak metni özetler.",
+    "Extract topics" : "Başlıklar ayıklansın",
+    "Extracts topics from a text and outputs them separated by commas." : "Bir metindeki konuları ayıklar ve bunları virgül ile ayırarak sıralar.",
+    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "%1$s uygulamasının dosyaları doğru şekilde değiştirilmedi. Sunucu ile uyumlu dosyaların yüklü olduğundan emin olun.",
+    "404" : "404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Oturum açmış kullanıcı bir yönetici, bir alt yönetici veya bu ayara erişmek için özel izne sahip olmalıdır",
+    "Logged in user must be an admin or sub admin" : "Oturum açmış kullanıcı bir yönetici ya da alt yönetici olmalıdır",
+    "Logged in user must be an admin" : "Oturum açmış kullanıcı bir yönetici olmalıdır",
+    "Full name" : "Tam ad",
+    "Unknown user" : "Kullanıcı bilinmiyor",
+    "Enter the database username and name for %s" : "%s için veri tabanı adını ve kullanıcı adını yazın",
+    "Enter the database username for %s" : "%s için veri tabanı kullanıcı adını yazın",
+    "MySQL username and/or password not valid" : "MySQL kullanıcı adı ya da parolası geçersiz",
+    "Oracle username and/or password not valid" : "Oracle kullanıcı adı ya da parolası geçersiz",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL kullanıcı adı ya da parolası geçersiz",
+    "Set an admin username." : "Bir yönetici kullanıcı adı yazın.",
+    "Sharing %s failed, because this item is already shared with user %s" : "%s paylaşılamadı. Bu öge zaten %s kullanıcısı ile paylaşılmış",
+    "The username is already being used" : "Bu kullanıcı adı zaten var",
+    "Could not create user" : "Kullanıcı oluşturulamadı",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Kullanıcı adında yalnızca şu karakterler kullanılabilir: \"a-z\", \"A-Z\", \"0-9\", boşluk ve \"_.@-'\"",
+    "A valid username must be provided" : "Geçerli bir kullanıcı adı yazmalısınız",
+    "Username contains whitespace at the beginning or at the end" : "Kullanıcı adının başı ya da sonunda boşluk var",
+    "Username must not consist of dots only" : "Kullanıcı adı yalnızca noktalardan oluşamaz",
+    "Username is invalid because files already exist for this user" : "Kullanıcı adı geçersiz, bu kullanıcı için zaten bazı dosyalar var",
+    "User disabled" : "Kullanıcı devre dışı",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 sürümü en az 2.7.0 olmalıdır. Şu anda %s kurulu.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Bu sorunu çözmek için libxml2 sürümünüzü güncelleyin ve site sunucusunu yeniden başlatın.",
+    "PostgreSQL >= 9 required." : "PostgreSQL >= 9 gerekli.",
+    "Please upgrade your database version." : "Lütfen veri tabanı sürümünüzü yükseltin.",
+    "Your data directory is readable by other users." : "Veri klasörünüz diğer kullanıcılar tarafından okunabilir.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Lütfen izinleri 0770 olarak ayarlayarak diğer kullanıcıların klasörü görebilmesini sağlayın."
 },
 "nplurals=2; plural=(n > 1);");
