@@ -1,8 +1,12 @@
 <?php
+
+declare(strict_types=1);
+
 /**
  * @copyright Copyright (c) 2016, ownCloud, Inc.
  *
  * @author Bernhard Posselt <dev@bernhard-posselt.com>
+ * @author Christoph Wurst <christoph@winzerhof-wurst.at>
  * @author Morris Jobke <hey@morrisjobke.de>
  *
  * @license AGPL-3.0
@@ -20,15 +24,18 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>
  *
  */
-
 namespace OCP\AppFramework;
 
 use Exception;
+use Psr\Container\ContainerExceptionInterface;
 
 /**
  * Class QueryException
  *
- * @package OCP\AppFramework
+ * The class extends `ContainerExceptionInterface` since 20.0.0
+ *
  * @since 8.1.0
+ * @deprecated 20.0.0 catch \Psr\Container\ContainerExceptionInterface
  */
-class QueryException extends Exception {}
+class QueryException extends Exception implements ContainerExceptionInterface {
+}
